@@ -65,7 +65,12 @@ static gint keypress_events_cb (GtkWidget *widget, GdkEventKey *event,
                                 FancyViewer *viewer);
 static void zoom_in_cb(GtkWidget *widget, GdkEvent *ev, FancyViewer *viewer);
 static void zoom_out_cb(GtkWidget *widget, GdkEvent *ev, FancyViewer *viewer);
+static gboolean fancy_prefs_cb(GtkWidget *widget, GdkEventButton *ev, FancyViewer *viewer);
 static void zoom_100_cb(GtkWidget *widget, GdkEvent *ev, FancyViewer *viewer);
+static void open_in_browser_cb(GtkWidget *widget, FancyViewer *viewer);
+static WebKitNavigationResponse fancy_open_uri (FancyViewer *viewer, gboolean external);
+static void fancy_create_popup_prefs_menu(FancyViewer *viewer);
+static void fancy_prefs_cache_init(FancyViewer *viewer);
 
 /*FIXME substitute webkitwebsettings.cpp functions with their API when available */
 gchar* webkit_web_view_get_selected_text(WebKitWebView* webView);
@@ -107,13 +112,25 @@ static gint fancy_show_mimepart_real(MimeViewer *_viewer)
         return FALSE;
     }
     if (procmime_get_part(viewer->filename, partinfo) < 0) {
-            g_free(viewer->filename);
+        g_free(viewer->filename);
+        viewer->filename = NULL;
     } else {
+        const gchar *charset = NULL;
+        if (_viewer && _viewer->mimeview &&
+            _viewer->mimeview->messageview->forced_charset)
+            charset = _viewer->mimeview->messageview->forced_charset;
+        else
+            charset = procmime_mimeinfo_get_parameter(partinfo, "charset");
+        if (!charset)
+            charset = conv_get_locale_charset_str();
+        debug_print("using %s charset\n", charset);
+        g_object_set(viewer->settings, "default-encoding", charset, NULL);
         gchar *tmp = g_filename_to_uri(viewer->filename, NULL, NULL);
+        debug_print("zoom_level: %i\n", fancy_prefs.zoom_level);
+        webkit_web_view_set_zoom_level(viewer->view, (fancy_prefs.zoom_level / 100.0));
         webkit_web_view_open(viewer->view, tmp);
         g_free(tmp);
     }
-    gtk_widget_grab_focus(GTK_WIDGET(viewer->view));
     viewer->loading = FALSE;
     return FALSE;
 }
@@ -182,6 +199,7 @@ static void fancy_print(MimeViewer *_viewer)
     debug_print("filename: %s\n", viewer->filename);
 	if (!viewer->filename) {
 		alertpanel_error(_("Filename is null."));
+        g_free(program);
 		return;
 	}
 
@@ -261,22 +279,24 @@ static gchar *fancy_get_selection (MimeViewer *_viewer)
 {
     debug_print("fancy_get_selection\n");
     FancyViewer *viewer = (FancyViewer *) _viewer;
-    
-    if (!viewer->view)
+    gchar *sel = webkit_web_view_get_selected_text(viewer->view);
+    if (!viewer->view || strlen(sel) == 0) {
+        g_free(sel);
         return NULL;
-    return webkit_web_view_get_selected_text(viewer->view); 
-
+    }
+    return sel; 
 }
 static void fancy_clear_viewer(MimeViewer *_viewer)
 {
     FancyViewer *viewer = (FancyViewer *) _viewer;
     GtkAdjustment *vadj;
     viewer->load_page = FALSE;    
+    viewer->override_prefs_block_links = FALSE;
+    viewer->override_prefs_external = FALSE;
     webkit_web_view_open(viewer->view, "about:blank");
     debug_print("fancy_clear_viewer\n");
+    fancy_prefs.zoom_level = webkit_web_view_get_zoom_level(viewer->view) * 100;
     viewer->to_load = NULL;
-    if(viewer->cur_link)
-        g_free(viewer->cur_link);
     vadj = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(viewer->scrollwin));
     vadj->value = 0.0;
     g_signal_emit_by_name(G_OBJECT(vadj), "value-changed", 0);
@@ -285,13 +305,96 @@ static void fancy_clear_viewer(MimeViewer *_viewer)
 static void fancy_destroy_viewer(MimeViewer *_viewer)
 {
     FancyViewer *viewer = (FancyViewer *) _viewer;
-
+    fancy_prefs.zoom_level = webkit_web_view_get_zoom_level(viewer->view) * 100;
     debug_print("fancy_destroy_viewer\n");
-
     g_free(viewer->filename);
     g_free(viewer);
 }
 
+static WebKitNavigationResponse fancy_open_uri (FancyViewer *viewer, gboolean external) {
+    if (viewer->load_page) {
+        /* handle mailto scheme */
+        if (!strncmp(viewer->cur_link,"mailto:", 7)) {
+            compose_new(NULL, viewer->cur_link + 7, NULL);
+            return WEBKIT_NAVIGATION_RESPONSE_IGNORE;
+        }
+        /* If we're not blocking, do we open with internal or external? */
+        else if(external) {
+            open_in_browser_cb(NULL, viewer);
+            return WEBKIT_NAVIGATION_RESPONSE_IGNORE;
+        }
+        else {
+            viewer->load_page = TRUE;
+            return WEBKIT_NAVIGATION_RESPONSE_ACCEPT;
+        }
+    } 
+    else {
+        viewer->load_page = TRUE;
+        return WEBKIT_NAVIGATION_RESPONSE_ACCEPT;
+    }
+}
+
+static WebKitNavigationResponse 
+navigation_requested_cb(WebKitWebView *view, WebKitWebFrame *frame, 
+                        WebKitNetworkRequest *netreq, FancyViewer *viewer)
+{
+
+    if (viewer->cache_prefs_auto_load_images != fancy_prefs.auto_load_images) {
+        viewer->cache_prefs_auto_load_images = fancy_prefs.auto_load_images;
+        if (!fancy_prefs.auto_load_images && !viewer->override_prefs_images) {
+            g_object_set(viewer->settings, 
+						"auto-load-images", FALSE, NULL);
+            webkit_web_view_set_settings(viewer->view, viewer->settings);
+        }
+        else {
+            g_object_set(viewer->settings, 
+						"auto-load-images", TRUE, NULL);
+            webkit_web_view_set_settings(viewer->view, viewer->settings);
+        }
+    }
+
+    if (viewer->cache_prefs_enable_scripts != fancy_prefs.enable_scripts) {
+        viewer->cache_prefs_enable_scripts = fancy_prefs.enable_scripts;
+        if (!fancy_prefs.enable_scripts && !viewer->override_prefs_scripts) {
+            g_object_set(viewer->settings, 
+						"enable-scripts", FALSE, NULL);
+            webkit_web_view_set_settings(viewer->view, viewer->settings);
+        }
+        else {
+            g_object_set(viewer->settings, 
+						"enable-scripts", TRUE, NULL);
+            webkit_web_view_set_settings(viewer->view, viewer->settings);
+        }
+    }
+    if (viewer->cache_prefs_enable_plugins != fancy_prefs.enable_plugins) {
+        viewer->cache_prefs_enable_plugins = fancy_prefs.enable_plugins;
+        if (!fancy_prefs.enable_plugins && !viewer->override_prefs_plugins) {
+            g_object_set(viewer->settings, 
+                         "enable-plugins", FALSE, NULL);
+            webkit_web_view_set_settings(viewer->view, viewer->settings);
+        }
+        else {
+            g_object_set(viewer->settings, 
+                         "enable-plugins", TRUE, NULL);
+            webkit_web_view_set_settings(viewer->view, viewer->settings);
+        }
+    }
+
+    if (fancy_prefs.block_links && !viewer->override_prefs_block_links) {
+        if (viewer->load_page)
+            return WEBKIT_NAVIGATION_RESPONSE_IGNORE; 
+    } 
+
+    if (viewer->cur_link) {
+        if (!fancy_prefs.open_external && !viewer->override_prefs_external)
+            return fancy_open_uri(viewer, FALSE);
+        else 
+            return fancy_open_uri(viewer, TRUE);
+    }
+
+    viewer->load_page = TRUE;
+    return WEBKIT_NAVIGATION_RESPONSE_ACCEPT;
+}
 static gboolean fancy_text_search(MimeViewer *_viewer, gboolean backward, 
                                      const gchar *str, gboolean case_sens)
 {
@@ -299,6 +402,121 @@ static gboolean fancy_text_search(MimeViewer *_viewer, gboolean backward,
                                          case_sens, !backward, TRUE);
 }
 
+static void fancy_auto_load_images_activated(GtkMenuItem *item, FancyViewer *viewer) {
+    viewer->load_page = FALSE;
+    viewer->override_prefs_images = TRUE;
+	viewer->cache_prefs_auto_load_images = !fancy_prefs.auto_load_images;
+    webkit_web_view_reload (viewer->view);
+    viewer->override_prefs_images = FALSE;
+}
+static void fancy_block_links_activated(GtkMenuItem *item, FancyViewer *viewer) {
+    viewer->override_prefs_block_links = TRUE;
+}
+static void fancy_enable_scripts_activated(GtkMenuItem *item, FancyViewer *viewer) {
+    viewer->load_page = FALSE;
+    viewer->override_prefs_scripts = TRUE;
+	viewer->cache_prefs_enable_scripts = !fancy_prefs.enable_scripts;
+    webkit_web_view_reload (viewer->view);
+    viewer->override_prefs_scripts = FALSE;
+}
+static void fancy_enable_plugins_activated(GtkMenuItem *item, FancyViewer *viewer) {
+    viewer->load_page = FALSE;
+    viewer->override_prefs_plugins = TRUE;
+	viewer->cache_prefs_enable_plugins = !fancy_prefs.enable_plugins;
+    webkit_web_view_reload (viewer->view);
+    viewer->override_prefs_plugins = FALSE;
+}
+static void fancy_open_external_activated(GtkMenuItem *item, FancyViewer *viewer) {
+    viewer->override_prefs_external = TRUE;
+
+}
+
+static gboolean fancy_prefs_cb(GtkWidget *widget, GdkEventButton *ev, FancyViewer *viewer)
+{
+    if ((ev->button == 1) && (ev->type == GDK_BUTTON_PRESS)) {
+        /* Set sensitivity according to preferences */
+        if (fancy_prefs.auto_load_images)
+            gtk_widget_set_sensitive(viewer->auto_load_images, FALSE);
+        else
+            gtk_widget_set_sensitive(viewer->auto_load_images, TRUE);
+        if (fancy_prefs.enable_scripts)
+            gtk_widget_set_sensitive(viewer->enable_scripts, FALSE);
+        else
+            gtk_widget_set_sensitive(viewer->enable_scripts, TRUE);
+        if (fancy_prefs.enable_plugins)
+            gtk_widget_set_sensitive(viewer->enable_plugins, FALSE);
+        else
+            gtk_widget_set_sensitive(viewer->enable_plugins, TRUE);
+        if (fancy_prefs.block_links)
+            gtk_widget_set_sensitive(viewer->block_links, TRUE);
+        else
+            gtk_widget_set_sensitive(viewer->block_links, FALSE);
+        if (fancy_prefs.open_external)
+            gtk_widget_set_sensitive(viewer->open_external, FALSE);
+        else
+            gtk_widget_set_sensitive(viewer->open_external, TRUE);
+
+        gtk_menu_popup(GTK_MENU(viewer->fancy_prefs_menu), NULL, NULL, NULL, NULL,
+                       ev->button, ev->time);
+        return TRUE;
+    }
+    return FALSE;
+}
+
+static void fancy_create_popup_prefs_menu(FancyViewer *viewer) {
+    GtkWidget *auto_load_images;
+    GtkWidget *item_image, *item_image2, *item_image3, *item_image4, *item_image5;
+    GtkWidget *block_links;
+    GtkWidget *enable_scripts;
+    GtkWidget *enable_plugins;
+    GtkWidget *open_external;
+
+    auto_load_images = gtk_image_menu_item_new_with_label(_("Load images"));
+    item_image = gtk_image_new_from_stock(GTK_STOCK_EXECUTE, GTK_ICON_SIZE_MENU);
+    gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(auto_load_images), item_image);
+
+    block_links = gtk_image_menu_item_new_with_label(_("Unblock links"));
+    item_image2 = gtk_image_new_from_stock(GTK_STOCK_EXECUTE, GTK_ICON_SIZE_MENU);
+    gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(block_links), item_image2);
+
+    enable_scripts = gtk_image_menu_item_new_with_label(_("Enable Javascript"));
+    item_image3 = gtk_image_new_from_stock(GTK_STOCK_EXECUTE, GTK_ICON_SIZE_MENU);
+    gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(enable_scripts), item_image3);
+    enable_plugins = gtk_image_menu_item_new_with_label(_("Enable Plugins"));
+    item_image4 = gtk_image_new_from_stock(GTK_STOCK_EXECUTE, GTK_ICON_SIZE_MENU);
+    gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(enable_plugins), item_image4);
+    open_external = gtk_image_menu_item_new_with_label(_("Open links with external browser"));
+    item_image5 = gtk_image_new_from_stock(GTK_STOCK_EXECUTE, GTK_ICON_SIZE_MENU);
+    gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(open_external), item_image5);
+
+    g_signal_connect(G_OBJECT(auto_load_images), "activate",
+                     G_CALLBACK (fancy_auto_load_images_activated), viewer);
+    g_signal_connect(G_OBJECT(block_links), "activate",
+                     G_CALLBACK (fancy_block_links_activated), viewer);
+    g_signal_connect(G_OBJECT(enable_scripts), "activate",
+                     G_CALLBACK (fancy_enable_scripts_activated), viewer);
+    g_signal_connect(G_OBJECT(enable_plugins), "activate",
+                     G_CALLBACK (fancy_enable_plugins_activated), viewer);
+    g_signal_connect(G_OBJECT(open_external), "activate",
+                     G_CALLBACK (fancy_open_external_activated), viewer);
+
+    gtk_menu_shell_append(GTK_MENU_SHELL(viewer->fancy_prefs_menu), auto_load_images);
+    gtk_menu_shell_append(GTK_MENU_SHELL(viewer->fancy_prefs_menu), block_links);
+    gtk_menu_shell_append(GTK_MENU_SHELL(viewer->fancy_prefs_menu), enable_scripts);
+    gtk_menu_shell_append(GTK_MENU_SHELL(viewer->fancy_prefs_menu), enable_plugins);
+    gtk_menu_shell_append(GTK_MENU_SHELL(viewer->fancy_prefs_menu), open_external);
+
+    gtk_menu_attach_to_widget(GTK_MENU(viewer->fancy_prefs_menu), viewer->ev_fancy_prefs, NULL);
+    gtk_widget_show_all(viewer->fancy_prefs_menu);
+
+    viewer->auto_load_images = auto_load_images;
+    viewer->enable_scripts = enable_scripts;
+    viewer->enable_plugins = enable_plugins;
+    viewer->block_links = block_links;
+    viewer->open_external = open_external;
+
+}
+
 static gboolean fancy_scroll_page(MimeViewer *_viewer, gboolean up)
 {
     FancyViewer *viewer = (FancyViewer *)_viewer;
@@ -345,12 +563,9 @@ static void over_link_cb(WebKitWebView *view, const gchar *wtf,
 {
     gtk_label_set_text(GTK_LABEL(viewer->l_link), link);
     if(link) {
-        if (viewer->cur_link) {
+        if (viewer->cur_link)
             g_free(viewer->cur_link);
-            viewer->cur_link = g_strdup(link);
-        } else {
-            viewer->cur_link = g_strdup(link);
-        }
+        viewer->cur_link = g_strdup(link);
     }
 }
 
@@ -373,54 +588,6 @@ static void stop_loading_cb(GtkWidget *widget, GdkEvent *ev,
     gtk_widget_hide(viewer->ev_stop_loading);
 }
 
-static WebKitNavigationResponse 
-navigation_requested_cb(WebKitWebView *view, WebKitWebFrame *frame, 
-                        WebKitNetworkRequest *netreq, FancyViewer *viewer)
-{
-    if (!fancy_prefs.auto_load_images) {
-        g_object_set(viewer->settings, 
-                    "auto-load-images", FALSE, NULL);
-        webkit_web_view_set_settings(viewer->view, viewer->settings);
-    }
-    else {
-        g_object_set(viewer->settings, 
-                    "auto-load-images", TRUE, NULL);
-        webkit_web_view_set_settings(viewer->view, viewer->settings);
-    }
-
-    if (!fancy_prefs.enable_scripts) {
-        g_object_set(viewer->settings, 
-                    "enable-scripts", FALSE, NULL);
-        webkit_web_view_set_settings(viewer->view, viewer->settings);
-    }
-    else {
-        g_object_set(viewer->settings, 
-                    "enable-scripts", TRUE, NULL);
-        webkit_web_view_set_settings(viewer->view, viewer->settings);
-    }
-    
-    if (!fancy_prefs.enable_plugins) {
-        g_object_set(viewer->settings, 
-                    "enable-plugins", FALSE, NULL);
-        webkit_web_view_set_settings(viewer->view, viewer->settings);
-    }
-    else {
-        g_object_set(viewer->settings, 
-                    "enable-plugins", TRUE, NULL);
-        webkit_web_view_set_settings(viewer->view, viewer->settings);
-    }
-
-    if (!fancy_prefs.block_links) {
-        if (viewer->load_page){
-            return WEBKIT_NAVIGATION_RESPONSE_IGNORE; 
-        }
-        else {
-            viewer->load_page = TRUE;
-        }
-    }
-
-    return WEBKIT_NAVIGATION_RESPONSE_ACCEPT;
-}
 static void search_the_web_cb(GtkWidget *widget, FancyViewer *viewer)
 {
     debug_print("Clicked on Search on Web\n");
@@ -474,9 +641,10 @@ static void viewer_menu_handler(GtkWidget *menuitem, FancyViewer *viewer)
                                 "Search the Web")) {
             gtk_label_set_text(GTK_LABEL(menul), _("Search the Web"));
                 
-            if (!fancy_prefs.block_links) {
+            if (fancy_prefs.block_links) {
                 gtk_widget_set_sensitive(GTK_WIDGET(menul), FALSE);
             } else {
+                viewer->cur_link = NULL;
                 GtkImageMenuItem *m_search = GTK_IMAGE_MENU_ITEM(menuitem);
                 g_signal_connect(G_OBJECT(m_search), "activate",
                                  G_CALLBACK(search_the_web_cb),
@@ -527,23 +695,10 @@ static void viewer_menu_handler(GtkWidget *menuitem, FancyViewer *viewer)
                              (gpointer *) viewer);
         }
 
-        if (!g_ascii_strcasecmp(gtk_label_get_text(GTK_LABEL(menul)), 
-                                                   "Open Image" )) {
-                
-            gtk_label_set_text(GTK_LABEL(menul), _("Open Image"));
-            gtk_widget_set_sensitive(GTK_WIDGET(menul), FALSE);
-                
-            GtkImageMenuItem *m_oimage = GTK_IMAGE_MENU_ITEM(menuitem);
-            g_signal_connect(G_OBJECT(m_oimage), "activate",
-                             G_CALLBACK(open_image_cb),
-                             (gpointer *) viewer);
-        }
-
         if (!g_ascii_strcasecmp(gtk_label_get_text(GTK_LABEL(menul)), 
                                                    "Save Image As" )) {
 
             gtk_label_set_text(GTK_LABEL(menul), _("Save Image As"));
-            gtk_widget_set_sensitive(GTK_WIDGET(menul), FALSE);
                 
             GtkImageMenuItem *m_simage = GTK_IMAGE_MENU_ITEM(menuitem);
             g_signal_connect(G_OBJECT(m_simage), "activate", 
@@ -554,7 +709,6 @@ static void viewer_menu_handler(GtkWidget *menuitem, FancyViewer *viewer)
                                 "Copy Image" )) {
                 
             gtk_label_set_text(GTK_LABEL(menul), _("Copy Image"));
-            gtk_widget_set_sensitive(GTK_WIDGET(menul), FALSE);
                 
             GtkImageMenuItem *m_cimage = GTK_IMAGE_MENU_ITEM(menuitem);
             g_signal_connect(G_OBJECT(m_cimage), "activate",
@@ -593,7 +747,7 @@ static gint keypress_events_cb (GtkWidget *widget, GdkEventKey *event,
     }
     return FALSE;
 }
-
+#if (WEBKIT_MICRO_VERSION < 12)
 static gboolean release_button_cb (WebKitWebView *view, GdkEvent *ev, 
                                    gpointer data)
 {
@@ -606,7 +760,7 @@ static gboolean release_button_cb (WebKitWebView *view, GdkEvent *ev,
     }
     return FALSE;
 }
-
+#endif
 static void zoom_100_cb(GtkWidget *widget, GdkEvent *ev, FancyViewer *viewer)
 {
     gtk_widget_grab_focus(widget);
@@ -624,6 +778,11 @@ static void zoom_out_cb(GtkWidget *widget, GdkEvent *ev, FancyViewer *viewer)
     webkit_web_view_zoom_out(viewer->view);
 }
 
+static void fancy_prefs_cache_init(FancyViewer *viewer) {
+    viewer->cache_prefs_auto_load_images = !fancy_prefs.auto_load_images;
+    viewer->cache_prefs_enable_plugins   = !fancy_prefs.enable_plugins;
+    viewer->cache_prefs_enable_scripts   = !fancy_prefs.enable_scripts;
+}
 static MimeViewer *fancy_viewer_create(void)
 {
     FancyViewer    *viewer;
@@ -664,7 +823,7 @@ static MimeViewer *fancy_viewer_create(void)
     viewer->vbox = gtk_vbox_new(FALSE, 0);
     hbox = gtk_hbox_new(FALSE, 0);
     viewer->progress = gtk_progress_bar_new();
-    
+    /* Zoom Widgets */
     viewer->zoom_100 = gtk_image_new_from_stock(GTK_STOCK_ZOOM_100, 
                                                 GTK_ICON_SIZE_MENU);
     viewer->zoom_in = gtk_image_new_from_stock(GTK_STOCK_ZOOM_IN, 
@@ -673,33 +832,40 @@ static MimeViewer *fancy_viewer_create(void)
                                                 GTK_ICON_SIZE_MENU);
     viewer->stop_loading = gtk_image_new_from_stock(GTK_STOCK_CANCEL, 
                                                     GTK_ICON_SIZE_MENU);
-
-    viewer->l_link = gtk_label_new("");
-
+    /* Event Widgets for the Zoom Widgets  */
     viewer->ev_zoom_100 = gtk_event_box_new();
     viewer->ev_zoom_in = gtk_event_box_new();
     viewer->ev_zoom_out = gtk_event_box_new();
     viewer->ev_stop_loading = gtk_event_box_new();
+    
+    /* Link Label */
+    viewer->l_link = gtk_label_new("");
 
+    /* Preferences Widgets to override preferences on the fly  */
+    viewer->fancy_prefs = gtk_image_new_from_stock(GTK_STOCK_PREFERENCES,
+                                                   GTK_ICON_SIZE_MENU);
+    viewer->ev_fancy_prefs = gtk_event_box_new();
 
-    gtk_event_box_set_visible_window(GTK_EVENT_BOX(viewer->ev_zoom_100), 
-                                     FALSE);
-    gtk_event_box_set_visible_window(GTK_EVENT_BOX(viewer->ev_zoom_in), 
-                                     FALSE);
-    gtk_event_box_set_visible_window(GTK_EVENT_BOX(viewer->ev_zoom_out), 
-                                     FALSE);
-    gtk_event_box_set_visible_window(GTK_EVENT_BOX(viewer->ev_stop_loading), 
-                                     FALSE);
+    /* Popup Menu for preferences  */
+    viewer->fancy_prefs_menu = gtk_menu_new();
+    fancy_create_popup_prefs_menu(viewer);
+
+    gtk_event_box_set_visible_window(GTK_EVENT_BOX(viewer->ev_zoom_100), FALSE);
+    gtk_event_box_set_visible_window(GTK_EVENT_BOX(viewer->ev_zoom_in), FALSE);
+    gtk_event_box_set_visible_window(GTK_EVENT_BOX(viewer->ev_zoom_out), FALSE);
+    gtk_event_box_set_visible_window(GTK_EVENT_BOX(viewer->ev_fancy_prefs), FALSE);
+    gtk_event_box_set_visible_window(GTK_EVENT_BOX(viewer->ev_stop_loading), FALSE);
 
     gtk_container_add(GTK_CONTAINER(viewer->ev_zoom_100), viewer->zoom_100);
     gtk_container_add(GTK_CONTAINER(viewer->ev_zoom_in), viewer->zoom_in);
     gtk_container_add(GTK_CONTAINER(viewer->ev_zoom_out), viewer->zoom_out);
-    gtk_container_add(GTK_CONTAINER(viewer->ev_stop_loading), 
-                                    viewer->stop_loading);
+    gtk_container_add(GTK_CONTAINER(viewer->ev_fancy_prefs), viewer->fancy_prefs);
+    gtk_container_add(GTK_CONTAINER(viewer->ev_stop_loading), viewer->stop_loading);
 
     gtk_box_pack_start(GTK_BOX(hbox), viewer->ev_zoom_100, FALSE, FALSE, 1);
     gtk_box_pack_start(GTK_BOX(hbox), viewer->ev_zoom_in, FALSE, FALSE, 2);
     gtk_box_pack_start(GTK_BOX(hbox), viewer->ev_zoom_out, FALSE, FALSE, 2);
+    gtk_box_pack_start(GTK_BOX(hbox), viewer->ev_fancy_prefs, FALSE, FALSE, 2);
     gtk_box_pack_start(GTK_BOX(hbox), viewer->l_link, FALSE, FALSE, 8);
     gtk_box_pack_end(GTK_BOX(hbox), viewer->progress, FALSE, FALSE, 0);
     gtk_box_pack_end(GTK_BOX(hbox), viewer->ev_stop_loading, FALSE, FALSE, 0);
@@ -711,11 +877,13 @@ static MimeViewer *fancy_viewer_create(void)
     gtk_widget_show(viewer->ev_zoom_100);
     gtk_widget_show(viewer->ev_zoom_in);
     gtk_widget_show(viewer->ev_zoom_out);
+    gtk_widget_show(viewer->ev_fancy_prefs);
 
     gtk_widget_show(viewer->scrollwin);
     gtk_widget_show(viewer->zoom_100);
     gtk_widget_show(viewer->zoom_in);
     gtk_widget_show(viewer->zoom_out);
+    gtk_widget_show(viewer->fancy_prefs);
     gtk_widget_show(viewer->stop_loading);
 
     gtk_widget_show(viewer->l_link);
@@ -735,21 +903,25 @@ static MimeViewer *fancy_viewer_create(void)
                      G_CALLBACK(navigation_requested_cb), viewer);
     g_signal_connect(G_OBJECT(viewer->view), "populate-popup",
                      G_CALLBACK(populate_popup_cb), viewer);
+#if (WEBKIT_MICRO_VERSION < 12)
     g_signal_connect(G_OBJECT(viewer->view), "button-release-event",
                      G_CALLBACK(release_button_cb), viewer);
+#endif
     g_signal_connect(G_OBJECT(viewer->ev_zoom_100), "button-press-event",
                      G_CALLBACK(zoom_100_cb), (gpointer*)viewer);
     g_signal_connect(G_OBJECT(viewer->ev_zoom_in), "button-press-event",
                      G_CALLBACK(zoom_in_cb), (gpointer *)viewer);
     g_signal_connect(G_OBJECT(viewer->ev_zoom_out), "button-press-event",
                      G_CALLBACK(zoom_out_cb), (gpointer *)viewer);
+    g_signal_connect(G_OBJECT(viewer->ev_fancy_prefs), "button-press-event",
+                     G_CALLBACK(fancy_prefs_cb), (gpointer *)viewer);
     g_signal_connect(G_OBJECT(viewer->ev_stop_loading), "button-press-event",
                      G_CALLBACK(stop_loading_cb), viewer);
     g_signal_connect(G_OBJECT(viewer->view), "key_press_event",
                      G_CALLBACK(keypress_events_cb), viewer);
 
     viewer->filename = NULL;
-
+    fancy_prefs_cache_init(viewer);
     return (MimeViewer *) viewer;
 }
 
@@ -795,7 +967,7 @@ const gchar *plugin_name(void)
 
 const gchar *plugin_desc(void)
 {
-    return g_strdup_printf("This plugin renders HTML e-mail using the WebKit" 
+    return g_strdup_printf("This plugin renders HTML mail using the WebKit " 
                            "%d.%d.%d library.", WEBKIT_MAJOR_VERSION, 
                            WEBKIT_MINOR_VERSION, WEBKIT_MICRO_VERSION);
 }
