@@ -160,7 +160,7 @@ css_parser_parse_escape (const gchar *p, gint start_pos, gint end_pos, gunichar
 	}
 	else if (c & 0x80) {
 		/* We have a (needlessly) escaped nonascii character */
-		g_error ("eek, we don't handle utf8 yet");
+		g_warning ("eek, we don't handle utf8 yet");
 	}
 
 	
@@ -581,7 +581,6 @@ css_parser_parse_term (const gchar *buffer, gint start_pos, gint end_pos, CssVal
 			}
 		}
 
-/*		g_error ("t1"); */
 		return -1;
 	}
 
@@ -807,7 +806,7 @@ css_parser_parse_simple_selector (const gchar *buffer, gint start_pos, gint end_
 			pos = css_parser_parse_ident (buffer, pos + 1, end_pos, &id);
 
 			if (pos == -1) {
-				g_error ("1. return -1");
+				g_warning ("1. return -1");
 				return -1;
 			}
 			
@@ -1166,9 +1165,14 @@ css_parser_parse_ruleset (const gchar *buffer, gint start_pos, gint end_pos, Css
 	cur_pos = pos + 1;
 	pos = css_parser_parse_to_char (buffer, '}', cur_pos, end_pos);
 
-	if (cur_pos == end_pos || sel == NULL)
+	if (cur_pos == end_pos || sel == NULL) {
+		gint i;
+
+		for (i = 0; i < n_sel; i++)
+			css_selector_destroy (sel[i]);
+		g_free (sel);
 		return pos + 1;
-	
+	}
 	if (pos == end_pos) {
 		gint i;
 
