@@ -2018,7 +2018,7 @@ html_view_text_updated (HtmlDocument *document, DomNode *node, HtmlView *view)
 		html_box_set_unrelayouted_up (box);
 	}
 	else {
-		g_error ("talk to the box factory here!");
+		g_warning ("talk to the box factory here!");
 	}
 
 	html_view_relayout_when_idle (view);
@@ -2177,7 +2177,7 @@ html_view_style_updated (HtmlDocument *document, DomNode *node, HtmlStyleChange
 	case HTML_STYLE_CHANGE_NONE:
 		break;
 	default:
-		g_error ("fix me!");
+		g_warning ("fix me!");
 	}
 }
 
@@ -2776,16 +2776,16 @@ html_view_add_move_binding (GtkBindingSet *binding_set, guint keyval, guint modm
 {
 	gtk_binding_entry_add_signal (binding_set, keyval, modmask,
 				      "move_cursor", 3,
-				      GTK_TYPE_ENUM, step,
-				      GTK_TYPE_INT, count,
-				      GTK_TYPE_BOOL, FALSE);
+				      G_TYPE_ENUM, step,
+				      G_TYPE_INT, count,
+				      G_TYPE_BOOLEAN, FALSE);
 
 	/* Selection-extending version */
 	gtk_binding_entry_add_signal (binding_set, keyval, modmask | GDK_SHIFT_MASK,
 				      "move_cursor", 3,
-				      GTK_TYPE_ENUM, step,
-				      GTK_TYPE_INT, count,
-				      GTK_TYPE_BOOL, TRUE);
+				      G_TYPE_ENUM, step,
+				      G_TYPE_INT, count,
+				      G_TYPE_BOOLEAN, TRUE);
 }
 
 static void
@@ -2936,7 +2936,7 @@ html_view_class_init (HtmlViewClass *klass)
 	GtkBindingSet *binding_set;
 
 	binding_set = gtk_binding_set_by_class (klass);
-	parent_class = gtk_type_class (GTK_TYPE_LAYOUT);
+	parent_class = g_type_class_peek (GTK_TYPE_LAYOUT);
 
 	object_class->finalize = html_view_finalize;
 
