@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -33,6 +33,8 @@ typedef struct _GtkHtmlBrowserPrefs	GtkHtmlBrowserPrefs;
 struct _GtkHtmlBrowserPrefs
 {
 	gboolean local;   /**< local browsing */
+	gboolean whitelist_ab;
+	gchar *whitelist_ab_folder;
 	gboolean cache_images;
 	gboolean clear_cache;
 };
