@@ -28,20 +28,28 @@
 #include <glib.h>
 #include "gettext.h"
 #include <gtk/gtk.h>
-#include <gdk/gdkx.h>
-#include "libgtkhtml/gtkhtml.h"
-#include "libgtkhtml/view/htmlselection.h"
-#include "libgtkhtml/layout/htmlbox.h"
-#include "libgtkhtml/layout/htmlboxtext.h"
+#ifndef G_OS_WIN32
 #if USE_PRINTUNIX
+#if GTK_CHECK_VERSION(2,13,1)
+#include <gtk/gtkunixprint.h>
+#else
 #include <gtk/gtkprintoperation.h>
 #include <gtk/gtkprintjob.h>
 #include <gtk/gtkprintunixdialog.h>
 #endif
+#endif
+#include <gdk/gdkx.h>
+#endif
+#include "libgtkhtml/gtkhtml.h"
+#include "libgtkhtml/view/htmlselection.h"
+#include "libgtkhtml/layout/htmlbox.h"
+#include "libgtkhtml/layout/htmlboxtext.h"
 #include "common/claws.h"
 #include "common/version.h"
 #include "main.h"
 #include "plugin.h"
+#include "mainwindow.h"
+#include "summaryview.h"
 #include "mimeview.h"
 #include "messageview.h"
 #include "prefs_common.h"
@@ -83,9 +91,7 @@ struct _GtkHtml2Viewer
 	gint		 stop_previous;
 	GMutex		*mutex;
 	GtkWidget 	*link_popupmenu;
-	GtkItemFactory 	*link_popupfactory;
 	GtkWidget	*context_popupmenu;
-	GtkItemFactory 	*context_popupfactory;
 	gboolean	 is_on_url;
 	gint		 last_search_match;
 	gboolean	 preparing;
@@ -95,26 +101,22 @@ struct _GtkHtml2Viewer
 static MimeViewerFactory gtkhtml2_viewer_factory;
 static gchar *gtkhtml2_viewer_tmpdir = NULL;
 
-static void gtkhtml_open_uri_cb			(GtkHtml2Viewer *viewer,
-						 guint		 action,
-						 void		*data);
-static void gtkhtml_copy_uri_cb			(GtkHtml2Viewer *viewer,
-						 guint		 action,
-						 void		*data);
-static void gtkhtml_zoom_cb			(GtkHtml2Viewer *viewer,
-						 guint		 action,
-						 void		*data);
+static void gtkhtml_open_uri_cb			(GtkAction	*action,
+						 GtkHtml2Viewer *viewer);
+static void gtkhtml_copy_uri_cb			(GtkAction	*action,
+						 GtkHtml2Viewer *viewer);
+static void gtkhtml_zoomin_cb			(GtkAction	*action,
+						 GtkHtml2Viewer *viewer);
+static void gtkhtml_zoomout_cb			(GtkAction	*action,
+						 GtkHtml2Viewer *viewer);
 
-static GtkItemFactoryEntry gtkhtml_link_popup_entries[] = 
+static GtkActionEntry gtkhtml_popup_entries[] = 
 {
-	{N_("/_Open with Web browser"),	NULL, gtkhtml_open_uri_cb, 0, NULL},
-	{N_("/Copy this _link"),	NULL, gtkhtml_copy_uri_cb, 0, NULL},
-};
-
-static GtkItemFactoryEntry gtkhtml_context_popup_entries[] = 
-{
-	{N_("/Zoom _in"),	NULL, gtkhtml_zoom_cb, 1, NULL},
-	{N_("/Zoom _out"),	NULL, gtkhtml_zoom_cb, 0, NULL},
+	{"GtkHtmlPopup",		NULL, "GtkHtmlPopup" },
+	{"GtkHtmlPopup/OpenBrowser",	NULL, N_("_Open with Web browser"), NULL, NULL, G_CALLBACK(gtkhtml_open_uri_cb) },
+	{"GtkHtmlPopup/CopyLink",	NULL, N_("Copy this _link"), NULL, NULL, G_CALLBACK(gtkhtml_copy_uri_cb) },
+	{"GtkHtmlPopup/ZoomIn",		NULL, N_("Zoom _in"), NULL, NULL, G_CALLBACK(gtkhtml_zoomin_cb) },
+	{"GtkHtmlPopup/ZoomOut",		NULL, N_("Zoom _out"), NULL, NULL, G_CALLBACK(gtkhtml_zoomout_cb) },
 };
 
 static void scrolled_cb (GtkAdjustment *adj, GtkHtml2Viewer *viewer)
@@ -202,6 +204,8 @@ static gboolean has_charset(FILE *fp)
 {
 	gchar buf[4096];
 	gint loaded = 0;
+
+	memset(buf, 0, sizeof(buf));
 	while ((loaded = fread(buf, 1, 4096, fp)) > 0) {
 		if (strcasestr(buf, "<meta") &&
 		    strcasestr(buf, "http-equiv") &&
@@ -219,6 +223,8 @@ static gboolean has_header(FILE *fp)
 	gchar buf[4096];
 	gint loaded = 0;
 	gboolean start = FALSE;
+	memset(buf, 0, sizeof(buf));
+
 	while ((loaded = fread(buf, 1, 4096, fp)) > 0) {
 		if (strcasestr(buf, "<head>")) {
 			start = TRUE;
@@ -236,6 +242,13 @@ static gboolean has_header(FILE *fp)
 	return FALSE;
 }
 
+static void gtkhtml2_restore_focus(void)
+{
+	MainWindow *mainwin = mainwindow_get_mainwindow();
+	if (mainwin)
+		summary_grab_focus(mainwin->summaryview);
+}
+
 static gint gtkhtml2_show_mimepart_real(MimeViewer *_viewer)
 {
 	GtkHtml2Viewer *viewer = (GtkHtml2Viewer *) _viewer;
@@ -251,7 +264,8 @@ static gint gtkhtml2_show_mimepart_real(MimeViewer *_viewer)
 	memset(buf, 0, sizeof(buf));
 
 	viewer->loading = 1;
-	messageview->updating = TRUE;
+	if (messageview)
+		messageview->updating = TRUE;
 	debug_print("gtkhtml2_show_mimepart\n");
 
 	if (viewer->filename != NULL) {
@@ -288,7 +302,7 @@ static gint gtkhtml2_show_mimepart_real(MimeViewer *_viewer)
 		
 		if (html_document_open_stream(viewer->html_doc, "text/html")) {
 			gboolean got_charset = FALSE;
-			fp = fopen(viewer->filename, "r");
+			fp = g_fopen(viewer->filename, "rb");
 
 			if (fp == NULL) {
 				html_document_close_stream(viewer->html_doc);
@@ -316,20 +330,27 @@ static gint gtkhtml2_show_mimepart_real(MimeViewer *_viewer)
 						g_free(meta_charset);
 						got_charset = TRUE;
 					} else if (insert_in_header && strcasestr(buf, "</head>")) {
+						gchar *tmp_buf = g_malloc(loaded+1);
 						gchar *start = NULL, *end = NULL;
 						gchar *meta_charset = g_strdup_printf(
 							"<meta http-equiv=Content-Type content=\"text/html; charset=%s\">",
 							charset);
-						start = g_strdup(buf);
+
+						strncpy(tmp_buf, buf, loaded);
+						tmp_buf[loaded] = '\0';
+
+						start = g_strdup(tmp_buf);
 						*(strcasestr(start, "</head>")) = '\0';
-						end = g_strdup(strcasestr(buf, "</head>"));
+						end = g_strdup(strcasestr(tmp_buf, "</head>"));
 						
 						html_document_write_stream(
 							viewer->html_doc, start, strlen(start));
 						html_document_write_stream(
 							viewer->html_doc, meta_charset, strlen(meta_charset));
-						strncpy(buf, end, sizeof(buf));
+						strncpy(buf, end, strlen(end));
+						loaded = strlen(end);
 						debug_print("injected %s in head\n", meta_charset);
+						g_free(tmp_buf);
 						g_free(meta_charset);
 						g_free(start);
 						g_free(end);
@@ -358,7 +379,8 @@ out:
 	viewer->stop_previous = FALSE;
 	viewer->force_image_loading = FALSE;	
 	g_mutex_unlock(viewer->mutex);
-	messageview->updating = FALSE;
+	if (messageview)
+		messageview->updating = FALSE;
 	viewer->preparing = FALSE;
 	return FALSE;
 }
@@ -376,7 +398,7 @@ static gint gtkhtml2_show_mimepart_prepare(MimeViewer *_viewer)
 	}
 
 	if (viewer->tag > 0) {
-		gtk_timeout_remove(viewer->tag);
+		g_source_remove(viewer->tag);
 		viewer->tag = -1;
 		if (viewer->loading) {
 			viewer->stop_previous = TRUE;
@@ -387,7 +409,7 @@ static gint gtkhtml2_show_mimepart_prepare(MimeViewer *_viewer)
 		g_mutex_unlock(viewer->mutex);
 		return TRUE;
 	}
-	viewer->tag = gtk_timeout_add(5, (GtkFunction)gtkhtml2_show_mimepart_real, viewer);
+	viewer->tag = g_timeout_add(5, (GtkFunction)gtkhtml2_show_mimepart_real, viewer);
 	g_mutex_unlock(viewer->mutex);
 	return FALSE;
 }
@@ -400,7 +422,7 @@ static void gtkhtml2_show_mimepart(MimeViewer *_viewer,
 	viewer->to_load = partinfo;
 	viewer->last_search_match = -1;
 	viewer->preparing = TRUE;
-	gtk_timeout_add(5, (GtkFunction)gtkhtml2_show_mimepart_prepare, viewer);
+	g_timeout_add(5, (GtkFunction)gtkhtml2_show_mimepart_prepare, viewer);
 }
 
 #ifdef HAVE_LIBCURL
@@ -408,6 +430,7 @@ static void reload_with_img(NoticeView *noticeview, GtkHtml2Viewer *viewer)
 {
 	viewer->force_image_loading = TRUE;
 	gtkhtml2_show_mimepart((MimeViewer *)viewer, NULL, viewer->mimeinfo);
+	gtkhtml2_restore_focus();
 }
 #endif
 
@@ -442,8 +465,8 @@ static void gtkhtml2_destroy_viewer(MimeViewer *_viewer)
 
 	debug_print("gtkhtml2_destroy_viewer\n");
 
-	gtk_widget_unref(GTK_WIDGET(viewer->html_view));
-	gtk_widget_unref(GTK_WIDGET(viewer->scrollwin));
+	g_object_unref(GTK_WIDGET(viewer->html_view));
+	g_object_unref(GTK_WIDGET(viewer->scrollwin));
 	claws_unlink(viewer->filename);
 	g_free(viewer->filename);
     	g_free(viewer);
@@ -485,7 +508,7 @@ static gchar *make_url(const gchar *url, const gchar *base)
 	}
 }
 
-static void gtkhtml_open_uri_cb (GtkHtml2Viewer *viewer, guint action, void *data)
+static void gtkhtml_open_uri_cb (GtkAction *action, GtkHtml2Viewer *viewer)
 {
 	gchar *uri = g_object_get_data(G_OBJECT(viewer->link_popupmenu),
 					   "uri");
@@ -494,7 +517,7 @@ static void gtkhtml_open_uri_cb (GtkHtml2Viewer *viewer, guint action, void *dat
 	g_free(uri);
 }
 
-static void gtkhtml_copy_uri_cb (GtkHtml2Viewer *viewer, guint action, void *data)
+static void gtkhtml_copy_uri_cb (GtkAction *action, GtkHtml2Viewer *viewer)
 {
 	gchar *uri = g_object_get_data(G_OBJECT(viewer->link_popupmenu),
 					   "uri");
@@ -539,6 +562,7 @@ void link_clicked(HtmlDocument *doc, const gchar *url, GtkHtml2Viewer *viewer) {
 			       bevent->button, bevent->time);
 	}
 	g_free(real_url);
+	gtkhtml2_restore_focus();
 }
 
 
@@ -548,7 +572,6 @@ void link_clicked(HtmlDocument *doc, const gchar *url, GtkHtml2Viewer *viewer) {
  */
 static void on_url(GtkWidget *widget, const gchar *url, gpointer data)
 {
-	gchar *trimmed_uri = NULL;
 	MimeViewer *viewer = (MimeViewer *)data;
 	MessageView *messageview = viewer->mimeview ? viewer->mimeview->messageview : NULL;
 
@@ -556,12 +579,10 @@ static void on_url(GtkWidget *widget, const gchar *url, gpointer data)
 
 	if (url != NULL) {
 		gchar *real_url = make_url(url, ((GtkHtml2Viewer *)data)->base);
-		trimmed_uri = trim_string(real_url?real_url:url, 60);
 		if (messageview->statusbar)
 			gtk_statusbar_push(GTK_STATUSBAR(messageview->statusbar),
-				   messageview->statusbar_cid, trimmed_uri);
+				   messageview->statusbar_cid, real_url);
 		g_free(real_url);
-		g_free(trimmed_uri);
 		((GtkHtml2Viewer *)viewer)->is_on_url = TRUE;
 	} else {
 		if (messageview->statusbar)
@@ -593,7 +614,7 @@ static void *gtkhtml_fetch_feed_threaded(void *arg)
 #endif
 
 	if (template != NULL)
-		f = fopen(template, "wb");
+		f = g_fopen(template, "wb");
 	if (f == NULL) {
 		perror("fdopen");
 		ctx->ready = TRUE;
@@ -609,16 +630,18 @@ static void *gtkhtml_fetch_feed_threaded(void *arg)
 		ctx->ready = TRUE;
 		claws_unlink(template);
 		g_free(template);
+		fclose(f);
 		return NULL;
 	}
 
 	curl_easy_setopt(eh, CURLOPT_URL, ctx->url);
 	curl_easy_setopt(eh, CURLOPT_NOPROGRESS, 1);
+	curl_easy_setopt(eh, CURLOPT_WRITEFUNCTION, NULL);
 	curl_easy_setopt(eh, CURLOPT_WRITEDATA, f);
 	curl_easy_setopt(eh, CURLOPT_FOLLOWLOCATION, 1);
 	curl_easy_setopt(eh, CURLOPT_MAXREDIRS, 3);
 #ifndef USE_PTHREAD
-	curl_easy_setopt(eh, CURLOPT_TIMEOUT, prefs_common.io_timeout_secs);
+	curl_easy_setopt(eh, CURLOPT_TIMEOUT, prefs_common_get_prefs()->io_timeout_secs);
 #endif
 #if LIBCURL_VERSION_NUM >= 0x070a00
 	curl_easy_setopt(eh, CURLOPT_SSL_VERIFYPEER, 0);
@@ -630,6 +653,7 @@ static void *gtkhtml_fetch_feed_threaded(void *arg)
 
 	res = curl_easy_perform(eh);
 
+	debug_print("res %d\n", res);
 	curl_easy_cleanup(eh);
 
 	fclose(f);
@@ -708,8 +732,6 @@ static void requested_url(HtmlDocument *doc, const gchar *url, HtmlStream *strea
 		gchar *cache_file = NULL;
 #endif
 		debug_print("looking for %s in Content-Location\n", url);
-                if (url == '\0')
-                        goto fail;
 
                 while ((mimeinfo = procmime_mimeinfo_next(mimeinfo)) != NULL) {
                         if (mimeinfo->location != NULL && strcmp(mimeinfo->location, url) == 0)
@@ -749,14 +771,18 @@ not_found_local:
 			if (is_file_exist(cache_file)) {
 				debug_print("cache file found (%s)\n", cache_file);
 				tmpfile = get_tmp_file();
+#ifdef G_OS_UNIX
 				if (link(cache_file, tmpfile) == 0) {
-					g_free(cache_file);
-					g_free(real_url);
-					goto found_local;
+#else
+				if (copy_file(cache_file, tmpfile, TRUE) == 0) {
+#endif
+						g_free(cache_file);
+						g_free(real_url);
+						goto found_local;
 				}
 			} 
 			debug_print("cache file not found (%s)\n", cache_file);
-			if (!viewer->force_image_loading && prefs_common.work_offline) {
+			if (!viewer->force_image_loading && prefs_common_get_prefs()->work_offline) {
 				remote_not_loaded = TRUE;
 				goto fail;
 			}
@@ -774,10 +800,10 @@ not_found_local:
 		        tmpfile = gtkhtml_fetch_feed_threaded(ctx);
 	        } else {
 		        /* Thread created, let's wait until it finishes */
-		        debug_print("gtkhtml: waiting for thread to finish\n");
+		        debug_print("gtkhtml: waiting %d secs for thread to finish \n", prefs_common_get_prefs()->io_timeout_secs);
 		        while( !ctx->ready ) {
 			        claws_do_idle();
-				if (time(NULL) - start_time > prefs_common.io_timeout_secs) {
+				if (time(NULL) - start_time > prefs_common_get_prefs()->io_timeout_secs) {
 					log_error(LOG_PROTOCOL, _("Timeout connecting to %s\n"), url);
 					pthread_cancel(pt);
 					ctx->ready = TRUE;
@@ -801,8 +827,10 @@ not_found_local:
 	        (gchar *)tmpfile = gtkhtml_fetch_feed_threaded(ctx);
 #endif
 		if (gtkhtml_prefs.cache_images && tmpfile) {
+#ifdef G_OS_UNIX
 			link(tmpfile, cache_file);
 			debug_print("cache file created (%s)\n", cache_file);
+#endif
 			g_free(cache_file);
 		}
 #else
@@ -811,9 +839,9 @@ not_found_local:
         }
 
 found_local:
-	debug_print("file %s\n", (char *)tmpfile);
+	debug_print("file %s\n", (char *)(tmpfile?tmpfile:""));
 	if (tmpfile) {
-		FILE *fp = fopen(tmpfile, "r");
+		FILE *fp = g_fopen(tmpfile, "rb");
 		if (fp == NULL) {
 			html_stream_close(stream);
 			claws_unlink(tmpfile);
@@ -826,8 +854,9 @@ found_local:
 		}
 
 		while ((loaded = fread(buffer, 1, sizeof(buffer), fp)) > 0) {
-			if (viewer->stop_previous || claws_is_exiting())
+			if (viewer->stop_previous || claws_is_exiting()) {
 				break;
+			}
 			html_stream_write(stream, buffer, loaded);
 			while (gtk_events_pending())
 				gtk_main_iteration();
@@ -851,7 +880,7 @@ fail:
 			NoticeView *noticeview = messageview->noticeview;
 			if (!load_images(viewer)) {
 				text = _("Remote images exist, but weren't loaded\naccording to your preferences.");
-			} else if (prefs_common.work_offline) {
+			} else if (prefs_common_get_prefs()->work_offline) {
 				text = _("Remote images exist, but weren't loaded\nbecause you are offline.");
 			} else {
 				text = _("Remote images exist, but loading them failed.");
@@ -1067,13 +1096,14 @@ static gboolean htmlview_scrolled(GtkWidget *widget, GdkEventScroll *event,
 	return FALSE;
 }
 
-static void gtkhtml_zoom_cb (GtkHtml2Viewer *viewer, guint action, void *data)
+static void gtkhtml_zoomin_cb (GtkAction *action, GtkHtml2Viewer *viewer)
 {
-	if (action == 1) {
-		html_view_zoom_in(HTML_VIEW(viewer->html_view));
-	} else {
-		html_view_zoom_out(HTML_VIEW(viewer->html_view));
-	}
+	html_view_zoom_in(HTML_VIEW(viewer->html_view));
+}
+
+static void gtkhtml_zoomout_cb (GtkAction *action, GtkHtml2Viewer *viewer)
+{
+	html_view_zoom_out(HTML_VIEW(viewer->html_view));
 }
 
 static gboolean htmlview_btn_released(GtkWidget *widget, GdkEventButton *event,
@@ -1086,7 +1116,7 @@ static gboolean htmlview_btn_released(GtkWidget *widget, GdkEventButton *event,
 	return FALSE;
 }
 
-#if GTK_CHECK_VERSION(2,10,0) && USE_PRINTUNIX
+#if GTK_CHECK_VERSION(2,10,0) && USE_PRINTUNIX && !defined(G_OS_WIN32)
 static void
 job_complete_cb (GtkPrintJob *print_job,
 		        GtkHtml2Viewer *viewer,
@@ -1130,6 +1160,7 @@ static void gtkhtml2_viewer_print(MimeViewer *mviewer)
 
 	if (viewer->filename == NULL) {
 		alertpanel_error(_("Filename is null."));
+		g_free(program);
 		return;
 	}
 
@@ -1214,11 +1245,8 @@ static MimeViewer *gtkhtml2_viewer_create(void)
 	GtkAdjustment *adj;
 	gfloat min_size = 0.0, min_size_new;
 	PangoFontDescription *font_desc = NULL;
-	gint n_entries;
-	GtkWidget *link_popupmenu;
-	GtkItemFactory *link_popupfactory;
-	GtkWidget *context_popupmenu;
-	GtkItemFactory *context_popupfactory;
+	GtkUIManager *ui_manager;
+	GtkActionGroup *action_group;
 
 	debug_print("gtkhtml2_viewer_create\n");
 
@@ -1232,7 +1260,7 @@ static MimeViewer *gtkhtml2_viewer_create(void)
 	viewer->mimeviewer.text_search = gtkhtml2_text_search;
 	viewer->mimeviewer.scroll_page = gtkhtml2_scroll_page;
 	viewer->mimeviewer.scroll_one_line = gtkhtml2_scroll_one_line;
-#if GTK_CHECK_VERSION(2,10,0) && USE_PRINTUNIX
+#if GTK_CHECK_VERSION(2,10,0) && USE_PRINTUNIX && !defined(G_OS_WIN32)
 	viewer->mimeviewer.print = gtkhtml2_viewer_print;
 #endif
 	viewer->html_doc = html_document_new();
@@ -1245,7 +1273,7 @@ static MimeViewer *gtkhtml2_viewer_create(void)
 	viewer->mutex     = g_mutex_new();
 
 	font_desc = pango_font_description_from_string
-			(prefs_common.textfont);
+			(prefs_common_get_prefs()->textfont);
 	min_size_new = (gfloat)(pango_font_description_get_size(font_desc)/PANGO_SCALE);
 	pango_font_description_free(font_desc);
 
@@ -1291,26 +1319,26 @@ static MimeViewer *gtkhtml2_viewer_create(void)
 			 G_CALLBACK(htmlview_btn_released), viewer);
 
 	gtk_widget_show(GTK_WIDGET(viewer->scrollwin));
-	gtk_widget_ref(GTK_WIDGET(viewer->scrollwin));
+	g_object_ref(GTK_WIDGET(viewer->scrollwin));
 	gtk_widget_show(GTK_WIDGET(viewer->html_view));
-	gtk_widget_ref(GTK_WIDGET(viewer->html_view));
+	g_object_ref(GTK_WIDGET(viewer->html_view));
 
-	n_entries = sizeof(gtkhtml_link_popup_entries) /
-		sizeof(gtkhtml_link_popup_entries[0]);
-	link_popupmenu = menu_create_items(gtkhtml_link_popup_entries, n_entries,
-				      "<UriPopupMenu>", &link_popupfactory,
-				      viewer);
-	viewer->link_popupmenu = link_popupmenu;
-	viewer->link_popupfactory = link_popupfactory;
+	ui_manager = gtk_ui_manager_new();
+	action_group = cm_menu_create_action_group_full(ui_manager,"GtkHtmlPopup", gtkhtml_popup_entries,
+			G_N_ELEMENTS(gtkhtml_popup_entries), (gpointer)viewer);
 
-	n_entries = sizeof(gtkhtml_context_popup_entries) /
-		sizeof(gtkhtml_context_popup_entries[0]);
-	context_popupmenu = menu_create_items(gtkhtml_context_popup_entries, n_entries,
-				      "<UriPopupMenu>", &context_popupfactory,
-				      viewer);
-	viewer->context_popupmenu = context_popupmenu;
-	viewer->context_popupfactory = context_popupfactory;
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/", "Menus", "Menus", GTK_UI_MANAGER_MENUBAR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Menus", "GtkHtmlLink", "GtkHtmlPopup", GTK_UI_MANAGER_MENU)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Menus/GtkHtmlLink", "OpenBrowser", "GtkHtmlPopup/OpenBrowser", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Menus/GtkHtmlLink", "CopyLink", "GtkHtmlPopup/CopyLink", GTK_UI_MANAGER_MENUITEM)
+	viewer->link_popupmenu = gtk_menu_item_get_submenu(GTK_MENU_ITEM(
+				gtk_ui_manager_get_widget(ui_manager, "/Menus/GtkHtmlLink")) );
 
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Menus", "GtkHtmlZoom", "GtkHtmlPopup", GTK_UI_MANAGER_MENU)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Menus/GtkHtmlZoom", "ZoomIn", "GtkHtmlPopup/ZoomIn", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Menus/GtkHtmlZoom", "ZoomOut", "GtkHtmlPopup/ZoomOut", GTK_UI_MANAGER_MENUITEM)
+	viewer->context_popupmenu = gtk_menu_item_get_submenu(GTK_MENU_ITEM(
+				gtk_ui_manager_get_widget(ui_manager, "/Menus/GtkHtmlZoom")) );
 	viewer->filename = NULL;
 
 	return (MimeViewer *) viewer;
@@ -1341,7 +1369,11 @@ gint plugin_init(gchar **error)
 	printf("%s\n", make_url("rel_url", "ftp://base/a/b"));
 	printf("%s\n", make_url("rel_url", "ftp://base/a/b/"));
 */
+#ifdef G_OS_UNIX
 	bindtextdomain(TEXTDOMAIN, LOCALEDIR);
+#else
+	bindtextdomain(TEXTDOMAIN, get_locale_dir());
+#endif
 	bind_textdomain_codeset(TEXTDOMAIN, "UTF-8");
 
 	gtkhtml2_viewer_tmpdir = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S,
