@@ -477,7 +477,7 @@ static void foldercheck_create_window(SpecificFolderArrayEntry *entry)
   gtk_container_set_border_width(GTK_CONTAINER(entry->window), 4);
   gtk_window_set_position(GTK_WINDOW(entry->window), GTK_WIN_POS_CENTER);
   gtk_window_set_modal(GTK_WINDOW(entry->window), TRUE);
-  gtk_window_set_policy(GTK_WINDOW(entry->window), FALSE, TRUE, FALSE);
+  gtk_window_set_resizable(GTK_WINDOW(entry->window), TRUE);
   gtk_window_set_wmclass
     (GTK_WINDOW(entry->window), "folder_selection", "Claws Mail");  
   g_signal_connect(G_OBJECT(entry->window), "delete_event",
@@ -522,9 +522,11 @@ static void foldercheck_create_window(SpecificFolderArrayEntry *entry)
   gtk_tree_view_set_search_column(GTK_TREE_VIEW(entry->treeview),
 				  FOLDERCHECK_FOLDERNAME);
   gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(entry->treeview),
-				  prefs_common.use_stripes_everywhere);
+				  prefs_common_get_prefs()->use_stripes_everywhere);
+#if GTK_CHECK_VERSION(2,10,0)
   gtk_tree_view_set_enable_tree_lines(GTK_TREE_VIEW(entry->treeview),
-				  prefs_common.enable_dotted_lines);
+				  prefs_common_get_prefs()->enable_dotted_lines);
+#endif
 
   selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(entry->treeview));
   gtk_tree_selection_set_mode(selection, GTK_SELECTION_BROWSE);
