@@ -51,6 +51,7 @@
 #include "defs.h"
 #include "inc.h"
 #include "common/utils.h"
+#include "main.h"
 
 #include "gettext.h"
 
@@ -63,6 +64,17 @@
 #include "parsers.h"
 #include "rssyl_prefs.h"
 
+static int rssyl_curl_progress_function(void *clientp,
+		double dltotal, double dlnow, double ultotal, double ulnow)
+{
+	if (claws_is_exiting()) {
+		debug_print("RSSyl: curl_progress_function bailing out, app is exiting\n");
+		return 1;
+	}
+
+	return 0;
+}
+
 struct _RSSylThreadCtx {
 	const gchar *url;
 	time_t last_update;
@@ -130,7 +142,8 @@ static void *rssyl_fetch_feed_threaded(void *arg)
 	debug_print("TEMPLATE: %s\n", template);
 
 	curl_easy_setopt(eh, CURLOPT_URL, ctx->url);
-	curl_easy_setopt(eh, CURLOPT_NOPROGRESS, 1);
+	curl_easy_setopt(eh, CURLOPT_NOPROGRESS, 0);
+	curl_easy_setopt(eh, CURLOPT_PROGRESSFUNCTION, rssyl_curl_progress_function);
 #if LIBCURL_VERSION_NUM < 0x071000
 	curl_easy_setopt(eh, CURLOPT_MUTE, 1);
 #endif
@@ -172,8 +185,10 @@ static void *rssyl_fetch_feed_threaded(void *arg)
 	res = curl_easy_perform(eh);
 
 	if (res != 0) {
-		if(res == CURLE_OPERATION_TIMEOUTED) {
+		if (res == CURLE_OPERATION_TIMEOUTED) {
 			log_error(LOG_PROTOCOL, RSSYL_LOG_ERROR_TIMEOUT, ctx->url);
+		} else if (res == CURLE_ABORTED_BY_CALLBACK) {
+			log_print(LOG_PROTOCOL, RSSYL_LOG_EXITING);
 		}
 		ctx->error = g_strdup(curl_easy_strerror(res));
 		ctx->ready = TRUE;
@@ -551,6 +566,17 @@ static RSSyl_HTMLSymbol symbol_list[] = {
 	{ "&#39;", "'" },
 	{ "&hellip;", "..." },
 	{ "&mdash;", "-" },
+	{ "<cite>", "\"" },
+	{ "</cite>", "\"" },
+	{ "<i>", "" },
+	{ "</i>", "" },
+	{ "<em>", "" },
+	{ "</em>", ""},
+	{ "<b>", "" },
+	{ "</b>", "" },
+	{ "<nobr>", "" },
+	{ "</nobr>", "" },
+	{ "<wbr>", "" },
 	{ NULL, NULL },
 };
 
@@ -575,29 +601,22 @@ gchar *rssyl_format_string(gchar *str, gboolean replace_html, gboolean replace_r
 	gchar *res = NULL;
 	gchar *tmp = NULL;
 
+	g_return_val_if_fail(str != NULL, NULL);
+
 	if (replace_html)
-		res = rssyl_replace_html_symbols(str);
+		tmp = rssyl_replace_html_symbols(str);
 	else
-		res = g_strdup(str);
+		tmp = g_strdup(str);
 
-	if (replace_returns) {
-		g_strdelimit(res, "\r\n", ' ');
-	}
+	res = rssyl_sanitize_string(tmp);
+	g_free(tmp);
 
-	g_strdelimit(res, "\t", ' ');
+	g_strstrip(res);
 
-	while (strstr(res, "  ")) {
-		tmp = rssyl_strreplace(res, "  ", " ");
-		g_free(res);
-		res = tmp;
-	}
-	res = strtailchomp(res, ' ');
-	strncpy(str, res, strlen(str));
-	g_free(res);
-	return str;
+	return res;
 }
 
-/* this functions splits a string into an array of string, by 
+/* this function splits a string into an array of string, by 
  * returning an array of pointers to positions of the delimiter
  * in the original string and replacing this delimiter with a
  * NULL. It does not duplicate memory, hence you should only
@@ -630,7 +649,7 @@ static gchar **strplit_no_copy(gchar *str, char delimiter)
  * Parse the RFC822-formatted feed item given by "path", and returns a
  * pointer to a RSSylFeedItem struct, which contains all required data.
  */
-static RSSylFeedItem *rssyl_parse_folder_item_file(gchar *path)
+static RSSylFeedItem *rssyl_parse_folder_item_file(gchar *dir_path, gchar *filename)
 {
 	gchar *contents, **lines, **line, **splid;
 	GError *error = NULL;
@@ -639,18 +658,21 @@ static RSSylFeedItem *rssyl_parse_folder_item_file(gchar *path)
 	gboolean parsing_headers, past_html_tag, past_endhtml_tag;
 	gboolean started_author = FALSE, started_subject = FALSE;
 	gboolean started_link = FALSE, started_clink = FALSE, started_plink = FALSE;
+	gchar *full_path = g_strconcat(dir_path, G_DIR_SEPARATOR_S, filename, NULL);
+	debug_print("RSSyl: parsing '%s'\n", full_path);
 
-	debug_print("RSSyl: parsing '%s'\n", path);
+	g_file_get_contents(full_path, &contents, NULL, &error);
 
-	g_file_get_contents(path, &contents, NULL, &error);
-
-	if( error )
+	if( error ) {
 		g_warning("GError: '%s'\n", error->message);
+		g_error_free(error);
+		error = NULL;
+	}
 
 	if( contents ) {
 		lines = strplit_no_copy(contents, '\n');
 	} else {
-		g_warning("Badly formatted file found, ignoring: '%s'\n", path);
+		g_warning("Badly formatted file found, ignoring: '%s'\n", full_path);
 		g_free(contents);
 		return NULL;
 	}
@@ -662,7 +684,9 @@ static RSSylFeedItem *rssyl_parse_folder_item_file(gchar *path)
 	fitem->text = NULL;
 	fitem->id = NULL;
 	fitem->id_is_permalink = FALSE;
-	fitem->realpath = g_strdup(path);
+	fitem->realpath = g_strdup(full_path);
+
+	g_free(full_path);
 
 	parsing_headers = TRUE;
 	past_html_tag = FALSE;
@@ -828,13 +852,10 @@ void rssyl_free_feeditem(RSSylFeedItem *item)
 	g_free(item);
 }
 
-/* rssyl_read_existing()
- *
- * Parse all existing folder items, storing their data in memory. Data is
- * later used for checking for duplicate entries.
- */
-void rssyl_read_existing(RSSylFolderItem *ritem)
+static void *rssyl_read_existing_thr(void *arg)
 {
+	RSSylParseCtx *ctx = (RSSylParseCtx *)arg;
+	RSSylFolderItem *ritem = ctx->ritem;
 	FolderItem *item = &ritem->item;
 	RSSylFeedItem *fitem = NULL;
 	DIR *dp;
@@ -842,12 +863,14 @@ void rssyl_read_existing(RSSylFolderItem *ritem)
 	gint num;
 	gchar *path;
 
-	debug_print("RSSyl: rssyl_read_existing()\n");
-
-	g_return_if_fail(ritem != NULL);
+	debug_print("RSSyl: rssyl_read_existing_thr()\n");
 
 	path = folder_item_get_path(item);
-	g_return_if_fail(path != NULL);
+	if( !path ) {
+		debug_print("RSSyl: read_existing - path is NULL, bailing out\n");
+		ctx->ready = TRUE;
+		return NULL;
+	}
 
 	/* create a new GSList, throw away the old one */
 	if( ritem->contents != NULL ) {
@@ -863,19 +886,26 @@ void rssyl_read_existing(RSSylFolderItem *ritem)
 
 	if( change_dir(path) < 0 ) {
 		g_free(path);
-		return;
+		return NULL;
 	}
 
 	if( (dp = opendir(".")) == NULL ) {
 		FILE_OP_ERROR(item->path, "opendir");
 		g_free(path);
-		return;
+		return NULL;
 	}
 
 	while( (d = readdir(dp)) != NULL ) {
+		if (claws_is_exiting()) {
+			closedir(dp);
+			g_free(path);
+			debug_print("RSSyl: read_existing is bailing out, app is exiting\n");
+			ctx->ready = TRUE;
+			return NULL;
+		}
 		if( (num = to_number(d->d_name)) > 0 && dirent_is_regular_file(d) ) {
 			debug_print("RSSyl: starting to parse '%s'\n", d->d_name);
-			if( (fitem = rssyl_parse_folder_item_file(d->d_name)) != NULL ) {
+			if( (fitem = rssyl_parse_folder_item_file(path, d->d_name)) != NULL ) {
 				debug_print("Appending '%s'\n", fitem->title);
 				ritem->contents = g_slist_prepend(ritem->contents, fitem);
 			}
@@ -886,7 +916,52 @@ void rssyl_read_existing(RSSylFolderItem *ritem)
 
 	ritem->contents = g_slist_reverse(ritem->contents);
 
-	debug_print("RSSyl: rssyl_read_existing() is returning\n");
+	ctx->ready = TRUE;
+
+	debug_print("RSSyl: rssyl_read_existing_thr() is returning\n");
+	return NULL;
+}
+
+/* rssyl_read_existing()
+ *
+ * Parse all existing folder items, storing their data in memory. Data is
+ * later used for checking for duplicate entries.
+ * Of course, actual work is done in a separate thread (if available) in
+ * rssyl_read_existing_thr().
+ */
+void rssyl_read_existing(RSSylFolderItem *ritem)
+{
+	RSSylParseCtx *ctx = NULL;
+#ifdef USE_PTHREAD
+	pthread_t pt;
+#endif
+
+	g_return_if_fail(ritem != NULL);
+
+	ctx = g_new0(RSSylParseCtx, 1);
+	ctx->ritem = ritem;
+	ctx->ready = FALSE;
+
+#ifdef USE_PTHREAD
+	if( pthread_create(&pt, PTHREAD_CREATE_JOINABLE, rssyl_read_existing_thr,
+				(void *)ctx) != 0 ) {
+		/* Couldn't create thread, continue nonthreaded */
+		rssyl_read_existing_thr(ctx);
+	} else {
+		debug_print("RSSyl: waiting for read_existing thread to finish\n");
+		while( !ctx->ready ) {
+			claws_do_idle();
+		}
+
+		debug_print("RSSyl: read_existing thread finished\n");
+		pthread_join(pt, NULL);
+	}
+#else
+	debug_print("RSSyl: pthreads not available, running read_existing non-threaded\n");
+	rssyl_read_existing_thr(ctx);
+#endif
+
+	g_free(ctx);
 }
 
 /* rssyl_cb_feed_compare()
@@ -1043,6 +1118,11 @@ void rssyl_parse_feed(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 
 	rssyl_read_existing(ritem);
 
+	if (claws_is_exiting()) {
+		debug_print("RSSyl: parse_feed bailing out, app is exiting\n");
+		return;
+	}
+
 	node = xmlDocGetRootElement(doc);
 
 	debug_print("RSSyl: XML - root node is '%s'\n", node->name);
@@ -1337,9 +1417,16 @@ void rssyl_update_comments(RSSylFolderItem *ritem)
 	}
 
 	while( (d = readdir(dp)) != NULL ) {
+		if (claws_is_exiting()) {
+			g_free(path);
+			closedir(dp);
+			debug_print("RSSyl: update_comments bailing out, app is exiting\n");
+			return;
+		}
+
 		if( (num = to_number(d->d_name)) > 0 && dirent_is_regular_file(d) ) {
 			debug_print("RSSyl: starting to parse '%s'\n", d->d_name);
-			if( (fitem = rssyl_parse_folder_item_file(d->d_name)) != NULL ) {
+			if( (fitem = rssyl_parse_folder_item_file(path, d->d_name)) != NULL ) {
 				xmlDocPtr doc;
 				gchar *title;
 				if (fitem->comments_link && fitem->id && 
@@ -1363,9 +1450,9 @@ void rssyl_update_comments(RSSylFolderItem *ritem)
 
 void rssyl_update_feed(RSSylFolderItem *ritem)
 {
-	gchar *title = NULL, *dir = NULL;
+	gchar *title = NULL, *dir = NULL, *error = NULL, *dir2, *tmp;
 	xmlDocPtr doc = NULL;
-	gchar *error = NULL;
+
 	g_return_if_fail(ritem != NULL);
 
 	if( !ritem->url )
@@ -1376,13 +1463,24 @@ void rssyl_update_feed(RSSylFolderItem *ritem)
 
 	doc = rssyl_fetch_feed(ritem->url, ritem->item.mtime, &title, &error);
 
+	if (claws_is_exiting()) {
+		debug_print("RSSyl: Claws-Mail is exiting, aborting feed parsing\n");
+		log_print(LOG_PROTOCOL, RSSYL_LOG_EXITING);
+		if (error)
+			g_free(error);
+		if (doc)
+			xmlFreeDoc(doc);
+		g_free(title);
+		g_free(dir);
+		return;
+	}
+
 	if (error) {
 		log_error(LOG_PROTOCOL, _("RSSyl: Cannot update feed %s:\n%s\n"), ritem->url, error);
 	}
 	g_free(error);
 
 	if (doc && title) {
-		gchar *dir2, *tmp;
 		tmp = rssyl_strreplace(title, "/", "\\");
 		dir = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, RSSYL_DIR,
 				G_DIR_SEPARATOR_S, tmp, NULL);
@@ -1398,6 +1496,7 @@ void rssyl_update_feed(RSSylFolderItem *ritem)
 				g_free(dir);
 				g_free(dir2);
 				g_free(title);
+				xmlFreeDoc(doc);
 				return;
 			}
 			g_free(dir2);
@@ -1414,10 +1513,30 @@ void rssyl_update_feed(RSSylFolderItem *ritem)
 
 		rssyl_parse_feed(doc, ritem, NULL);
 
+		if (claws_is_exiting()) {
+			debug_print("RSSyl: Claws-Mail is exiting, aborting feed parsing\n");
+			log_print(LOG_PROTOCOL, RSSYL_LOG_EXITING);
+			if (error)
+				g_free(error);
+			if (doc)
+				xmlFreeDoc(doc);
+			g_free(title);
+			g_free(dir);
+			return;
+		}
+
 		rssyl_expire_items(ritem);
 	}
 
-	if( ritem->fetch_comments == TRUE )
+	if (claws_is_exiting()) {
+		g_free(title);
+		g_free(dir);
+		if (doc)
+			xmlFreeDoc(doc);
+		return;
+	}
+
+	if( ritem->fetch_comments == TRUE)
 		rssyl_update_comments(ritem);
 
 	ritem->item.mtime = time(NULL);
@@ -1508,7 +1627,7 @@ static RSSylFolderItem *rssyl_find_feed_by_url(gchar *url)
 FolderItem *rssyl_subscribe_new_feed(FolderItem *parent, const gchar *url, 
 				  gboolean verbose)
 {
-	gchar *title;
+	gchar *title = NULL;
 	xmlDocPtr doc;
 	FolderItem *new_item;
 	RSSylFolderItem *ritem;
@@ -1548,7 +1667,9 @@ FolderItem *rssyl_subscribe_new_feed(FolderItem *parent, const gchar *url,
 			log_error(LOG_PROTOCOL, _("Couldn't fetch URL '%s':\n%s\n"), myurl, error ? error:_("Unknown error"));
 		g_free(myurl);
 		g_free(error);
-		xmlFreeDoc(doc);
+		g_free(title);
+		if (doc)
+			xmlFreeDoc(doc);
 		return NULL;
 	}
 
