@@ -46,64 +46,86 @@
 
 static char *rssyl_popup_menu_labels[] =
 {
-	N_("/_Refresh feed"),
-	N_("/Refresh _all feeds"),
-	"/---",
-	N_("/Subscribe _new feed..."),
-	N_("/_Unsubscribe feed..."),
-	N_("/Feed pr_operties..."),
-	"/---",
-	N_("/Rena_me..."),
-	"/---",
-	N_("/_Create new folder..."),
-	N_("/_Delete folder..."),
-	"/---",
-	N_("/Remove folder _tree..."),
-	"/---",
+	N_("_Refresh feed"),
+	N_("Refresh _all feeds"),
+	N_("Subscribe _new feed..."),
+	N_("_Unsubscribe feed..."),
+	N_("Feed pr_operties..."),
+	N_("Import feed list..."),
+	N_("Rena_me..."),
+	N_("_Create new folder..."),
+	N_("_Delete folder..."),
+	N_("Remove folder _tree..."),
 	NULL
 };
 
-static void rssyl_set_sensitivity(GtkItemFactory *ifac, FolderItem *item)
+static GtkActionEntry rssyl_popup_entries[] = 
+{
+	{"FolderViewPopup/RefreshFeed",		NULL, NULL, NULL, NULL, G_CALLBACK(rssyl_refresh_cb) },
+	{"FolderViewPopup/RefreshAllFeeds",	NULL, NULL, NULL, NULL, G_CALLBACK(rssyl_refresh_all_cb) },
+
+	{"FolderViewPopup/NewFeed",		NULL, NULL, NULL, NULL, G_CALLBACK(rssyl_new_feed_cb) },
+	{"FolderViewPopup/RemoveFeed",		NULL, NULL, NULL, NULL, G_CALLBACK(rssyl_remove_feed_cb) },
+	{"FolderViewPopup/FeedProperties",	NULL, NULL, NULL, NULL, G_CALLBACK(rssyl_prop_cb) },
+	{"FolderViewPopup/ImportFeedlist",	NULL, NULL, NULL, NULL, G_CALLBACK(rssyl_import_feed_list_cb) },
+
+	{"FolderViewPopup/RenameFolder",	NULL, NULL, NULL, NULL, G_CALLBACK(rssyl_rename_cb) },
+
+	{"FolderViewPopup/NewFolder",		NULL, NULL, NULL, NULL, G_CALLBACK(rssyl_new_folder_cb) },
+	{"FolderViewPopup/RemoveFolder",	NULL, NULL, NULL, NULL, G_CALLBACK(rssyl_remove_folder_cb) },
+
+	{"FolderViewPopup/RemoveMailbox",	NULL, NULL, NULL, NULL, G_CALLBACK(rssyl_remove_rss_cb) },
+
+};
+
+static void rssyl_add_menuitems(GtkUIManager *ui_manager, FolderItem *item)
+{
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "RefreshFeed", "FolderViewPopup/RefreshFeed", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "RefreshAllFeeds", "FolderViewPopup/RefreshAllFeeds", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorRSS1", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "NewFeed", "FolderViewPopup/NewFeed", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "RemoveFeed", "FolderViewPopup/RemoveFeed", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "FeedProperties", "FolderViewPopup/FeedProperties", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "ImportFeedlist", "FolderViewPopup/ImportFeedlist", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorRSS2", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "RenameFolder", "FolderViewPopup/RenameFolder", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorRSS3", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "NewFolder", "FolderViewPopup/NewFolder", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "RemoveFolder", "FolderViewPopup/RemoveFolder", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorRSS4", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "RemoveMailbox", "FolderViewPopup/RemoveMailbox", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorRSS5", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+}
+
+static void rssyl_set_sensitivity(GtkUIManager *ui_manager, FolderItem *item)
 {
 #define SET_SENS(name, sens) \
-	menu_set_sensitive(ifac, name, sens)
+	cm_menu_set_sensitive_full(ui_manager, "Popup/"name, sens)
+
 	RSSylFolderItem *ritem = (RSSylFolderItem *)item;
-	SET_SENS(_("/Refresh feed"), folder_item_parent(item) != NULL && ritem->url);
-	SET_SENS(_("/Refresh all feeds"), folder_item_parent(item) == NULL );
-	SET_SENS(_("/Subscribe new feed..."), TRUE);
-	SET_SENS(_("/Unsubscribe feed..."), folder_item_parent(item) != NULL && ritem->url );
-	SET_SENS(_("/Feed properties..."), folder_item_parent(item) != NULL && ritem->url );
-	SET_SENS(_("/Rename..."), folder_item_parent(item) != NULL );
-	SET_SENS(_("/Create new folder..."), TRUE );
-	SET_SENS(_("/Delete folder..."), folder_item_parent(item) != NULL && !ritem->url );
-	SET_SENS(_("/Remove folder tree..."), folder_item_parent(item) == NULL );
+	SET_SENS("FolderViewPopup/RefreshFeed", folder_item_parent(item) != NULL && ritem->url);
+	SET_SENS("FolderViewPopup/RefreshAllFeeds", folder_item_parent(item) == NULL );
+	SET_SENS("FolderViewPopup/NewFeed", TRUE);
+	SET_SENS("FolderViewPopup/ImportFeedlist", TRUE );
+	SET_SENS("FolderViewPopup/RemoveFeed", folder_item_parent(item) != NULL && ritem->url );
+	SET_SENS("FolderViewPopup/FeedProperties", folder_item_parent(item) != NULL && ritem->url );
+	SET_SENS("FolderViewPopup/RenameFolder", folder_item_parent(item) != NULL );
+	SET_SENS("FolderViewPopup/NewFolder", TRUE );
+	SET_SENS("FolderViewPopup/RemoveFolder", folder_item_parent(item) != NULL && !ritem->url );
+	SET_SENS("FolderViewPopup/RemoveMailbox", folder_item_parent(item) == NULL );
 
 #undef SET_SENS
 }
 
-static GtkItemFactoryEntry rssyl_popup_entries[] =
-{
-	{ NULL, NULL, rssyl_refresh_cb, 0, NULL },
-	{ NULL, NULL, rssyl_refresh_all_cb, 0, NULL },
-	{ NULL, NULL, NULL, 0, "<Separator>" },
-	{ NULL, NULL, rssyl_new_feed_cb, 0, NULL },
-	{ NULL, NULL, rssyl_remove_feed_cb, 0, NULL },
-	{ NULL, NULL, rssyl_prop_cb, 0, NULL },
-	{ NULL, NULL, NULL, 0, "<Separator>" },
-	{ NULL, NULL, rssyl_rename_cb, 0, NULL },
-	{ NULL, NULL, NULL, 0, "<Separator>" },
-	{ NULL, NULL, rssyl_new_folder_cb, 0, NULL },
-	{ NULL, NULL, rssyl_remove_folder_cb, 0, NULL },
-	{ NULL, NULL, NULL, 0, "<Separator>" },
-	{ NULL, NULL, rssyl_remove_rss_cb, 0, NULL },
-	{ NULL, NULL, NULL, 0, "<Separator>" }
-};
-
 static FolderViewPopup rssyl_popup =
 {
 	"rssyl",
 	"<rssyl>",
-	NULL,
+	rssyl_popup_entries,
+	G_N_ELEMENTS(rssyl_popup_entries),
+	NULL, 0,
+	NULL, 0, 0, NULL,
+	rssyl_add_menuitems,
 	rssyl_set_sensitivity
 };
 
@@ -112,15 +134,15 @@ static void rssyl_fill_popup_menu_labels(void)
 	gint i;
 
 	for( i = 0; rssyl_popup_menu_labels[i] != NULL; i++ ) {
-		(rssyl_popup_entries[i]).path = _(rssyl_popup_menu_labels[i]);
+		(rssyl_popup_entries[i]).label = _(rssyl_popup_menu_labels[i]);
 	}
 }
 
-static void rssyl_add_mailbox(gpointer callback_data, guint callback_action,
-		GtkWidget *widget)
+static void rssyl_add_mailbox(GtkAction *action, gpointer callback_data)
 {
 	MainWindow *mainwin = (MainWindow *) callback_data;
 	gchar *path;
+	gchar *base = NULL;
 	Folder *folder;
 
 	path = input_dialog(_("Add RSS folder tree"),
@@ -134,8 +156,10 @@ static void rssyl_add_mailbox(gpointer callback_data, guint callback_action,
 		return;
 	}
 
+	base = g_path_get_basename(path);
 	folder = folder_new(folder_get_class_from_string("rssyl"),
-			g_basename(path), path);
+			base, path);
+	g_free(base);
 
 	if( folder->klass->create_tree(folder) < 0 ) {
 		alertpanel_error(_("Creation of folder tree failed.\n"
@@ -151,40 +175,31 @@ static void rssyl_add_mailbox(gpointer callback_data, guint callback_action,
 	folderview_set(mainwin->folderview);
 }
 
-static GtkItemFactoryEntry mainwindow_add_mailbox = {
-	N_("/File/Add mailbox/RSSyl..."),
-	NULL,
-	rssyl_add_mailbox,
-	0,
-	NULL
-};
+static GtkActionEntry mainwindow_add_mailbox[] = {{
+	"File/AddMailbox/RSSyl",
+	NULL, N_("RSSyl..."), NULL, NULL, G_CALLBACK(rssyl_add_mailbox)
+}};
+
+static guint main_menu_id = 0;
 
 void rssyl_gtk_init(void)
 {
-	GtkItemFactory *ifac;
 	MainWindow *mainwin = mainwindow_get_mainwindow();
-	guint i, n;
 
-	ifac = gtk_item_factory_from_widget(mainwin->menubar);
-	gtk_item_factory_create_item(ifac, &mainwindow_add_mailbox, mainwin, 1);
+	gtk_action_group_add_actions(mainwin->action_group, mainwindow_add_mailbox,
+			1, (gpointer)mainwin);
+	MENUITEM_ADDUI_ID_MANAGER(mainwin->ui_manager, "/Menu/File/AddMailbox", "RSSyl", 
+			  "File/AddMailbox/RSSyl", GTK_UI_MANAGER_MENUITEM,
+			  main_menu_id)
+
 
 	rssyl_fill_popup_menu_labels();
-
-	n = sizeof(rssyl_popup_entries) /
-		sizeof(rssyl_popup_entries[0]);
-
-	for( i = 0; i < n; i++ )
-		rssyl_popup.entries = g_slist_append(rssyl_popup.entries,
-				&rssyl_popup_entries[i]);
-
 	folderview_register_popup(&rssyl_popup);
 }
 
 void rssyl_gtk_done(void)
 {
-	GtkItemFactory *ifac;
 	MainWindow *mainwin = mainwindow_get_mainwindow();
-	GtkWidget *widget;
 	FolderView *folderview = NULL;
 	FolderItem *fitem = NULL;
 
@@ -201,10 +216,8 @@ void rssyl_gtk_done(void)
 
 	folderview_unregister_popup(&rssyl_popup);
 
-	ifac = gtk_item_factory_from_widget(mainwin->menubar);
-	widget = gtk_item_factory_get_widget(ifac, mainwindow_add_mailbox.path);
-	gtk_widget_destroy(widget);
-	gtk_item_factory_delete_item(ifac, mainwindow_add_mailbox.path);
+	MENUITEM_REMUI_MANAGER(mainwin->ui_manager,mainwin->action_group, "File/AddMailbox/RSSyl", main_menu_id);
+	main_menu_id = 0;
 }
 
 /***********************************************/
@@ -217,7 +230,7 @@ static RSSylFeedProp *rssyl_gtk_prop_real(RSSylFolderItem *ritem)
 						*expired_label, *hsep, *sep, *bbox, *cancel_button, *cancel_align,
 						*cancel_hbox, *cancel_image, *cancel_label, *ok_button, *ok_align,
 						*ok_hbox, *ok_image, *ok_label;
-	GtkObject *refresh_adj, *expired_adj;
+	GtkObject *refresh_adj, *expired_adj, *fetch_comments_for_adj;
 	gint refresh, expired;
 	gint row = 0;
 
@@ -259,6 +272,12 @@ static RSSylFeedProp *rssyl_gtk_prop_real(RSSylFolderItem *ritem)
 			GTK_TOGGLE_BUTTON(feedprop->fetch_comments),
 			ritem->fetch_comments);
 
+	/* Refresh interval spinbutton */
+	fetch_comments_for_adj = gtk_adjustment_new(ritem->fetch_comments_for,
+			-1, 100000, 1, 10, 10);
+	feedprop->fetch_comments_for = gtk_spin_button_new(GTK_ADJUSTMENT(fetch_comments_for_adj),
+			1, 0);
+
 	if( ritem->default_expired_num )
 		expired = rssyl_prefs_get()->expired;
 	else
@@ -309,6 +328,23 @@ static RSSylFeedProp *rssyl_gtk_prop_real(RSSylFolderItem *ritem)
 			(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 			(GtkAttachOptions) (0), 10, 0);
 	row++;
+
+	/* Fetch comments for - label */
+	refresh_label = gtk_label_new(_("<b>Fetch comments on posts aged less than:</b>\n"
+			"<small>(In days; set to -1 to fetch all comments)"
+			"</small>"));
+	gtk_label_set_use_markup(GTK_LABEL(refresh_label), TRUE);
+	gtk_misc_set_alignment(GTK_MISC(refresh_label), 0, 0.5);
+	gtk_table_attach(GTK_TABLE(table), refresh_label, 0, 1, row, row+1,
+			(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+			(GtkAttachOptions) (0), 10, 5);
+
+	/* Fetch comments for - spinbutton */
+	gtk_table_attach(GTK_TABLE(table), feedprop->fetch_comments_for, 1, 2, row, row+1,
+			(GtkAttachOptions) (0),
+			(GtkAttachOptions) (0), 10, 5);
+	row++;
+
 	hsep = gtk_hseparator_new();
 	gtk_widget_set_size_request(hsep, -1, 10);
 	gtk_table_attach(GTK_TABLE(table), hsep, 0, 2, row, row+1,
@@ -500,6 +536,9 @@ void rssyl_gtk_prop_store(RSSylFolderItem *ritem)
 	ritem->fetch_comments = gtk_toggle_button_get_active(
 			GTK_TOGGLE_BUTTON(ritem->feedprop->fetch_comments));
 
+	ritem->fetch_comments_for = gtk_spin_button_get_value_as_int(
+				GTK_SPIN_BUTTON(ritem->feedprop->fetch_comments_for));
+
 	if (!old_fetch_comments && ritem->fetch_comments) {
 		/* reset the RSSylFolderItem's mtime to be sure we get all 
 		 * available comments */
