@@ -30,6 +30,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <curl/curl.h>
 #include <curl/curlver.h>
+#include "combobox.h"
 
 #include "vcalendar.h"
 #include "vcal_folder.h"
@@ -67,6 +68,7 @@ struct _VCalMeeting
 	GtkWidget *start_time;
 	GtkWidget *end_c;
 	GtkWidget *end_time;
+	GtkWidget *location;
 	GtkWidget *summary;
 	GtkWidget *description;
 	GSList 	  *attendees;
@@ -79,7 +81,9 @@ struct _VCalMeeting
 	GtkWidget *total_avail_msg;
 	PrefsAccount *account;
 	gboolean visible;
+#if !GTK_CHECK_VERSION(2,12,0)
 	GtkTooltips *tips;
+#endif
 };
 
 struct _VCalAttendee {
@@ -109,7 +113,7 @@ VCalAttendee *attendee_add(VCalMeeting *meet, gchar *address, gchar *name, gchar
 	GtkWidget *s_hbox = NULL;						\
 	if (do_space) {								\
 		spacer = gtk_label_new("");					\
-		gtk_widget_set_usize(spacer, 18, 16);				\
+		gtk_widget_set_size_request(spacer, 18, 16);				\
 		s_hbox = gtk_hbox_new(FALSE, 6);				\
 		gtk_box_pack_start(GTK_BOX(s_hbox), spacer, FALSE, FALSE, 0);	\
 		gtk_box_pack_start(GTK_BOX(s_hbox), widget, TRUE, TRUE, 0);	\
@@ -147,7 +151,7 @@ VCalAttendee *attendee_add(VCalMeeting *meet, gchar *address, gchar *name, gchar
 	GtkWidget *s_hbox = NULL;						\
 	if (do_space) {								\
 		spacer = gtk_label_new("");					\
-		gtk_widget_set_usize(spacer, 18, 16);				\
+		gtk_widget_set_size_request(spacer, 18, 16);				\
 		s_hbox = gtk_hbox_new(FALSE, 6);				\
 		gtk_box_pack_start(GTK_BOX(s_hbox), spacer, FALSE, FALSE, 0);	\
 		gtk_box_pack_start(GTK_BOX(s_hbox), widget, TRUE, TRUE, 0);	\
@@ -223,6 +227,10 @@ static gint get_dtdate(const gchar *str, gint field)
 	
 	tzset();
 
+#ifdef G_OS_WIN32
+	if (t < 0)
+		t = 1;
+#endif
 	lt = localtime_r(&t, &buft);
 
 	switch(field){
@@ -263,6 +271,10 @@ VCalAttendee *attendee_add(VCalMeeting *meet, gchar *address, gchar *name, gchar
 {
 	GtkWidget *att_hbox = gtk_hbox_new(FALSE, 6);
 	VCalAttendee *attendee 	= g_new0(VCalAttendee, 1);
+#if !(GTK_CHECK_VERSION(2,12,0))
+	GtkTooltips *tips = meet->tips;
+#endif
+
 	attendee->address	= gtk_entry_new();
 	attendee->cutype	= gtk_combo_box_new_text();
 	attendee->avail_evtbox  = gtk_event_box_new();
@@ -273,9 +285,8 @@ VCalAttendee *attendee_add(VCalMeeting *meet, gchar *address, gchar *name, gchar
 	gtk_widget_show(attendee->cutype);
 	gtk_widget_show(attendee->avail_evtbox);
 
-	gtk_tooltips_set_tip(meet->tips, attendee->address, 
-				_("Use <tab> to autocomplete from addressbook"), NULL);
-	gtk_widget_set_usize(attendee->avail_evtbox, 18, 16);
+	CLAWS_SET_TIP(attendee->address, _("Use <tab> to autocomplete from addressbook"));
+	gtk_widget_set_size_request(attendee->avail_evtbox, 18, 16);
 	gtk_event_box_set_visible_window(GTK_EVENT_BOX(attendee->avail_evtbox), FALSE);
 	gtk_container_add (GTK_CONTAINER(attendee->avail_evtbox), attendee->avail_img);
 
@@ -372,15 +383,15 @@ static gchar *get_organizer_name(VCalMeeting *meet)
 		return g_strdup("");
 }
 
-static void get_time_from_combo(GtkCombo *combo, int *h, int *m)
+static void get_time_from_combo(GtkWidget *combo, int *h, int *m)
 {
 	gchar *tmp;
 	gchar **parts;
-	
+
 	if (!h || !m) 
 		return;
 
-	tmp = gtk_editable_get_chars(GTK_EDITABLE(combo->entry), 0, -1);
+	tmp = gtk_editable_get_chars(GTK_EDITABLE(gtk_bin_get_child(GTK_BIN(combo))), 0, -1);
 	parts = g_strsplit(tmp, ":", 2);
 	if (parts[0] && parts[1] && *parts[0] && *parts[1]) {
 		*h = atoi(parts[0]);
@@ -398,6 +409,10 @@ static int get_current_gmt_offset(void)
 	
 	tzset();
 
+#ifdef G_OS_WIN32
+	if (now < 0)
+		now = 1;
+#endif
 	gmtime_r(& now, & gmt);
 	localtime_r(& now, & local);
 	
@@ -412,6 +427,10 @@ static int get_gmt_offset_at_time(time_t then)
 	
 	tzset();
 
+#ifdef G_OS_WIN32
+	if (then < 0)
+		then = 1;
+#endif
 	gmtime_r(& then, & gmt);
 	localtime_r(& then, & local);
 	
@@ -430,6 +449,10 @@ static gchar *get_date(VCalMeeting *meet, int start)
 	tzset();
 
 	t = time(NULL);
+#ifdef G_OS_WIN32
+	if (t < 0)
+		t = 1;
+#endif
 	lt = localtime_r(&t, &buft);
 	
 	gtk_calendar_get_date(GTK_CALENDAR(start ? meet->start_c : meet->end_c), &y, &m, &d);
@@ -441,11 +464,11 @@ static gchar *get_date(VCalMeeting *meet, int start)
 	lt->tm_sec  = 0;
 
 	if (start) {
-		get_time_from_combo(GTK_COMBO(meet->start_time), &lt->tm_hour, &lt->tm_min);
+		get_time_from_combo(meet->start_time, &lt->tm_hour, &lt->tm_min);
 	} else {
-		get_time_from_combo(GTK_COMBO(meet->end_time), &lt->tm_hour, &lt->tm_min);
+		get_time_from_combo(meet->end_time, &lt->tm_hour, &lt->tm_min);
 	}
-	
+
 	debug_print("%d %d %d, %d:%d\n", lt->tm_mday, lt->tm_mon, lt->tm_year, lt->tm_hour, lt->tm_min);
 	t = mktime(lt);
 
@@ -456,6 +479,11 @@ static gchar *get_date(VCalMeeting *meet, int start)
 	return g_strdup(icaltime_as_ical_string(icaltime_from_timet(t, FALSE)));
 }
 
+static gchar *get_location(VCalMeeting *meet)
+{
+	return gtk_editable_get_chars(GTK_EDITABLE(meet->location),0, -1);
+}
+
 static gchar *get_summary(VCalMeeting *meet) 
 {
 	return gtk_editable_get_chars(GTK_EDITABLE(meet->summary),0, -1);
@@ -525,28 +553,32 @@ static void meeting_start_changed(GtkWidget *widget, gpointer data)
 	guint d, m, y;
 	int num = -1;
 
-	if (strlen(gtk_entry_get_text(
-		   GTK_ENTRY(GTK_COMBO(meet->start_time)->entry))) < 5)
+	if (strlen(gtk_entry_get_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(meet->start_time))))) < 5)
 		return;
-
 	tzset();
 
 	start_t = time(NULL);
 	end_t = time(NULL);
+#ifdef G_OS_WIN32
+	if (start_t < 0)
+		start_t = 1;
+	if (end_t < 0)
+		end_t = 1;
+#endif
 	localtime_r(&start_t, &start_lt);
 	localtime_r(&end_t, &end_lt);
 
 	gtk_calendar_get_date(GTK_CALENDAR(meet->start_c), &y, &m, &d);
 	start_lt.tm_mday = d; start_lt.tm_mon  = m; start_lt.tm_year = y - 1900;
-	get_time_from_combo(GTK_COMBO(meet->start_time), &start_lt.tm_hour, &start_lt.tm_min);
+	get_time_from_combo(meet->start_time, &start_lt.tm_hour, &start_lt.tm_min);
 
 	start_t = mktime(&start_lt);
 	debug_print("start %s\n", ctime(&start_t));
 
 	gtk_calendar_get_date(GTK_CALENDAR(meet->end_c), &y, &m, &d);
 	end_lt.tm_mday = d; end_lt.tm_mon  = m; end_lt.tm_year = y - 1900;
-	get_time_from_combo(GTK_COMBO(meet->end_time), &end_lt.tm_hour, &end_lt.tm_min);
 
+	get_time_from_combo(meet->end_time, &end_lt.tm_hour, &end_lt.tm_min);
 	end_t = mktime(&end_lt);
 
 	debug_print("end   %s\n", ctime(&end_t));
@@ -557,10 +589,14 @@ static void meeting_start_changed(GtkWidget *widget, gpointer data)
 	}
 	end_t = start_t + 3600;
 
+#ifdef G_OS_WIN32
+	if (end_t < 0)
+		end_t = 1;
+#endif
 	localtime_r(&end_t, &end_lt);
 	debug_print("n %d %d %d, %d:%d\n", end_lt.tm_mday, end_lt.tm_mon, end_lt.tm_year, end_lt.tm_hour, end_lt.tm_min);
 
-	g_signal_handlers_block_by_func(GTK_COMBO(meet->end_time)->entry, meeting_end_changed, meet);
+	g_signal_handlers_block_by_func(gtk_bin_get_child(GTK_BIN(meet->end_time)), meeting_end_changed, meet);
 	g_signal_handlers_block_by_func(meet->end_c, meeting_end_changed, meet);
 
 	gtk_calendar_select_day(GTK_CALENDAR(meet->end_c), end_lt.tm_mday);
@@ -570,17 +606,19 @@ static void meeting_start_changed(GtkWidget *widget, gpointer data)
 				end_lt.tm_year + 1900);
 
 	num = get_list_item_num(end_lt.tm_hour, end_lt.tm_min);
-	if (num > -1)
-		gtk_list_select_item(GTK_LIST(GTK_COMBO(meet->end_time)->list), num);
-	else {
+	if (num > -1) {
+		gchar *time_text = g_strdup_printf("%02d:%02d", end_lt.tm_hour, end_lt.tm_min);
+		combobox_select_by_text(GTK_COMBO_BOX(meet->end_time), time_text);
+		g_free(time_text);
+	} else {
 		gchar *tmp = g_strdup_printf("%02d:%02d",
 				end_lt.tm_hour, 
 				end_lt.tm_min);
-		gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(meet->end_time)->entry),
+		gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(meet->end_time))),
 				   tmp);
 		g_free(tmp);
 	}
-	g_signal_handlers_unblock_by_func(GTK_COMBO(meet->end_time)->entry, meeting_end_changed, meet);
+	g_signal_handlers_unblock_by_func(gtk_bin_get_child(GTK_BIN(meet->end_time)), meeting_end_changed, meet);
 	g_signal_handlers_unblock_by_func(meet->end_c, meeting_end_changed, meet);
 }
 
@@ -593,27 +631,32 @@ static void meeting_end_changed(GtkWidget *widget, gpointer data)
 	guint d, m, y;
 	int num = -1;
 
-	if (strlen(gtk_entry_get_text(
-		   GTK_ENTRY(GTK_COMBO(meet->end_time)->entry))) < 5)
+	if (strlen(gtk_entry_get_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(meet->end_time))))) < 5)
 		return;
 	start_t = time(NULL);
 	end_t = time(NULL);
 
 	tzset();
 
+#ifdef G_OS_WIN32
+	if (start_t < 0)
+		start_t = 1;
+	if (end_t < 0)
+		end_t = 1;
+#endif
 	localtime_r(&start_t, &start_lt);
 	localtime_r(&end_t, &end_lt);
 	
 	gtk_calendar_get_date(GTK_CALENDAR(meet->start_c), &y, &m, &d);
 	start_lt.tm_mday = d; start_lt.tm_mon  = m; start_lt.tm_year = y - 1900;
-	get_time_from_combo(GTK_COMBO(meet->start_time), &start_lt.tm_hour, &start_lt.tm_min);
+	get_time_from_combo(meet->start_time, &start_lt.tm_hour, &start_lt.tm_min);
 
 	start_t = mktime(&start_lt);
 	debug_print("start %s\n", ctime(&start_t));
 
 	gtk_calendar_get_date(GTK_CALENDAR(meet->end_c), &y, &m, &d);
 	end_lt.tm_mday = d; end_lt.tm_mon  = m; end_lt.tm_year = y - 1900;
-	get_time_from_combo(GTK_COMBO(meet->end_time), &end_lt.tm_hour, &end_lt.tm_min);
+	get_time_from_combo(meet->end_time, &end_lt.tm_hour, &end_lt.tm_min);
 
 	end_t = mktime(&end_lt);
 
@@ -627,10 +670,14 @@ static void meeting_end_changed(GtkWidget *widget, gpointer data)
 	
 	tzset();
 
+#ifdef G_OS_WIN32
+	if (start_t < 0)
+		start_t = 1;
+#endif
 	localtime_r(&start_t, &start_lt);
 	debug_print("n %d %d %d, %d:%d\n", start_lt.tm_mday, start_lt.tm_mon, start_lt.tm_year, start_lt.tm_hour, start_lt.tm_min);
 
-	g_signal_handlers_block_by_func(GTK_COMBO(meet->start_time)->entry, meeting_start_changed, meet);
+	g_signal_handlers_block_by_func(gtk_bin_get_child(GTK_BIN(meet->start_time)), meeting_start_changed, meet);
 	g_signal_handlers_block_by_func(meet->start_c, meeting_start_changed, meet);
 
 	gtk_calendar_select_day(GTK_CALENDAR(meet->start_c), start_lt.tm_mday);
@@ -640,24 +687,29 @@ static void meeting_end_changed(GtkWidget *widget, gpointer data)
 				start_lt.tm_year + 1900);
 
 	num = get_list_item_num(start_lt.tm_hour, start_lt.tm_min);
-	if (num > -1)
-		gtk_list_select_item(GTK_LIST(GTK_COMBO(meet->start_time)->list), num);
-	else {
+	if (num > -1) {
+		gchar *time_text = g_strdup_printf("%02d:%02d", start_lt.tm_hour, start_lt.tm_min);
+		combobox_select_by_text(GTK_COMBO_BOX(meet->start_time), time_text);
+		g_free(time_text);
+	} else {
 		gchar *tmp = g_strdup_printf("%02d:%02d",
 				start_lt.tm_hour, 
 				start_lt.tm_min);
-		gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(meet->start_time)->entry),
+		gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(meet->start_time))),
 				   tmp);
 		g_free(tmp);
 	}
 
-	g_signal_handlers_unblock_by_func(GTK_COMBO(meet->start_time)->entry, meeting_start_changed, meet);
+	g_signal_handlers_unblock_by_func(gtk_bin_get_child(GTK_BIN(meet->start_time)), meeting_start_changed, meet);
 	g_signal_handlers_unblock_by_func(meet->start_c, meeting_start_changed, meet);
 }
 
 static void att_update_icon(VCalMeeting *meet, VCalAttendee *attendee, gint avail, gchar *text)
 {
 	const gchar *icon = GTK_STOCK_DIALOG_INFO;
+#if !(GTK_CHECK_VERSION(2,12,0))
+	GtkTooltips *tips = meet->tips;
+#endif
 
 	switch (avail) {
 		case 0:  icon = GTK_STOCK_DIALOG_WARNING;	break;
@@ -669,14 +721,14 @@ static void att_update_icon(VCalMeeting *meet, VCalAttendee *attendee, gint avai
 		if (attendee->avail_img) {
 			gtk_widget_hide(attendee->avail_img);
 		}
-		gtk_tooltips_set_tip(meet->tips, attendee->avail_evtbox, NULL, NULL);
+		CLAWS_SET_TIP(attendee->avail_evtbox, NULL);
 	} else if (attendee->avail_img) {
 		gtk_image_set_from_stock
 		        (GTK_IMAGE(attendee->avail_img), 
 			icon, 
 			GTK_ICON_SIZE_SMALL_TOOLBAR);
 		gtk_widget_show(attendee->avail_img);
-		gtk_tooltips_set_tip(meet->tips, attendee->avail_evtbox, text, NULL);
+		CLAWS_SET_TIP(attendee->avail_evtbox, text);
 	}
 }
 
@@ -803,11 +855,14 @@ static gboolean find_availability(const gchar *dtstart, const gchar *dtend, GSLi
 	gchar *msg = NULL;
 	struct icaltimetype start = icaltime_from_string(dtstart);
 	struct icaltimetype end = icaltime_from_string(dtend);
-	AlertValue val;
+	AlertValue val = G_ALERTALTERNATE;
 	gint total = 0;
 	GHashTable *avail_table_avail = g_hash_table_new(NULL, g_direct_equal);
 	GHashTable *avail_table_before = g_hash_table_new(NULL, g_direct_equal);
 	GHashTable *avail_table_after = g_hash_table_new(NULL, g_direct_equal);
+#if !(GTK_CHECK_VERSION(2,12,0))
+	GtkTooltips *tips = meet->tips;
+#endif
 	
 	for (cur = attendees; cur; cur = cur->next) {
 		VCalAttendee *attendee = (VCalAttendee *)cur->data;
@@ -930,7 +985,7 @@ static gboolean find_availability(const gchar *dtstart, const gchar *dtend, GSLi
 	gtk_widget_show(meet->total_avail_img);
 	gtk_label_set_text(GTK_LABEL(meet->total_avail_msg), _("Not everyone is available. "
 				"See tooltips for more info..."));
-	gtk_tooltips_set_tip(meet->tips, meet->total_avail_evtbox, msg, NULL);
+	CLAWS_SET_TIP(meet->total_avail_evtbox, msg);
 	g_free(msg);
 	return (val == G_ALERTALTERNATE);
 }
@@ -953,6 +1008,9 @@ static gboolean check_attendees_availability(VCalMeeting *meet, gboolean tell_if
 				"internal.ifb", NULL);
 	gboolean local_only = FALSE;
 	GSList *attlist;
+#if !(GTK_CHECK_VERSION(2,12,0))
+	GtkTooltips *tips = meet->tips;
+#endif
 
 	if (vcalprefs.freebusy_get_url == NULL
 	||  *vcalprefs.freebusy_get_url == '\0') {
@@ -1107,7 +1165,7 @@ static gboolean check_attendees_availability(VCalMeeting *meet, gboolean tell_if
 					GTK_ICON_SIZE_SMALL_TOOLBAR);
 				gtk_widget_show(meet->total_avail_img);
 				gtk_label_set_text(GTK_LABEL(meet->total_avail_msg), _("Everyone is available."));
-				gtk_tooltips_set_tip(meet->tips, meet->total_avail_evtbox, NULL, NULL);
+				CLAWS_SET_TIP(meet->total_avail_evtbox, NULL);
 			} else {
 				gtk_image_set_from_stock
 		        		(GTK_IMAGE(meet->total_avail_img), 
@@ -1115,8 +1173,7 @@ static gboolean check_attendees_availability(VCalMeeting *meet, gboolean tell_if
 					GTK_ICON_SIZE_SMALL_TOOLBAR);
 				gtk_widget_show(meet->total_avail_img);
 				gtk_label_set_text(GTK_LABEL(meet->total_avail_msg), _("Everyone is available."));
-				gtk_tooltips_set_tip(meet->tips, meet->total_avail_evtbox, 
-					_("Everyone seems available, but some free/busy information failed to be retrieved."), NULL);
+				CLAWS_SET_TIP(meet->total_avail_evtbox, _("Everyone seems available, but some free/busy information failed to be retrieved."));
 			}
 		}
 	}
@@ -1162,6 +1219,7 @@ static gboolean send_meeting_cb(GtkButton *widget, gpointer data)
 	gchar *dtstart = NULL;
 	gchar *dtend = NULL;
 	gchar *tzid = NULL;
+	gchar *location = NULL;
 	gchar *summary = NULL;
 	gchar *description = NULL;
 	VCalEvent *event = NULL;
@@ -1204,7 +1262,7 @@ static gboolean send_meeting_cb(GtkButton *widget, gpointer data)
 	} else {
 		g_snprintf(buf, sizeof(buf), "%s", "");
 	}
-	generate_msgid(buf, 255);
+	generate_msgid(buf, 255, account->address);
 
 	if (meet->uid) {
 		uid 	= g_strdup(meet->uid);
@@ -1214,10 +1272,11 @@ static gboolean send_meeting_cb(GtkButton *widget, gpointer data)
 
 	dtstart		= get_date(meet, TRUE);
 	dtend		= get_date(meet, FALSE);
+	location	= get_location(meet);
 	summary		= get_summary(meet);
 	description	= get_description(meet);
 	
-	event = vcal_manager_new_event(uid, organizer, organizer_name, summary, description,
+	event = vcal_manager_new_event(uid, organizer, organizer_name, location, summary, description,
 					dtstart, dtend, NULL, tzid, NULL, meet->method, 
 					meet->sequence,
 					ICAL_VEVENT_COMPONENT);
@@ -1274,6 +1333,7 @@ static gboolean send_meeting_cb(GtkButton *widget, gpointer data)
 	g_free(dtstart);
 	g_free(dtend);
 	g_free(description);
+	g_free(location);
 	g_free(summary);
 	vcal_manager_free_event(event);
 
@@ -1295,7 +1355,6 @@ static gboolean send_meeting_cb(GtkButton *widget, gpointer data)
 	if (folder && redisp) {
 		MainWindow *mainwin = mainwindow_get_mainwindow();
 		summary_show(mainwin->summaryview, folder->inbox);
-		vcal_folder_refresh_cal(folder->inbox);
 	}
 
 	return res;
@@ -1325,15 +1384,20 @@ static VCalMeeting *vcal_meeting_create_real(VCalEvent *event, gboolean visible)
 	GtkWidget *scrolledwin;
 	GList *times = NULL;
 	GList *accounts;
+	GtkListStore *menu;
+	gchar *time_text = NULL;
 #ifdef GENERIC_UMPC
 	GtkWidget *notebook;
 	GtkWidget *maemo_vbox0;
 #endif
-	
+	CLAWS_TIP_DECL();
+
 	if (!watch_cursor)
 		watch_cursor = gdk_cursor_new(GDK_WATCH);
 
-	meet->tips = gtk_tooltips_new();
+#if !(GTK_CHECK_VERSION(2,12,0))
+    	meet->tips = tips;
+#endif
 	meet->visible = visible;
 	start_h_adj = gtk_adjustment_new (0, 0, 23, 1, 10, 10);
 	start_m_adj = gtk_adjustment_new (0, 0, 59, 1, 10, 10);
@@ -1358,16 +1422,20 @@ static VCalMeeting *vcal_meeting_create_real(VCalEvent *event, gboolean visible)
 
 	times = get_predefined_times();
 
-	meet->start_time 	= gtk_combo_new();
-	gtk_combo_set_popdown_strings(GTK_COMBO(meet->start_time), times);
-	gtk_combo_set_value_in_list(GTK_COMBO(meet->start_time), FALSE, FALSE);
-	meet->end_time 		= gtk_combo_new();
-	gtk_combo_set_popdown_strings(GTK_COMBO(meet->end_time), times);
-	gtk_combo_set_value_in_list(GTK_COMBO(meet->end_time), FALSE, FALSE);
+	meet->start_time 	= gtk_combo_box_entry_new_text ();
+	gtk_combo_box_set_active(GTK_COMBO_BOX(meet->start_time), -1);
+	menu = GTK_LIST_STORE(gtk_combo_box_get_model(GTK_COMBO_BOX(meet->start_time)));
+	combobox_set_popdown_strings(GTK_COMBO_BOX(meet->start_time), times);
+
+	meet->end_time 		= gtk_combo_box_entry_new_text ();
+	gtk_combo_box_set_active(GTK_COMBO_BOX(meet->end_time), -1);
+	menu = GTK_LIST_STORE(gtk_combo_box_get_model(GTK_COMBO_BOX(meet->end_time)));
+	combobox_set_popdown_strings(GTK_COMBO_BOX(meet->end_time), times);
 
 	list_free_strings(times);
 	g_list_free(times);
 
+	meet->location  	= gtk_entry_new();
 	meet->summary		= gtk_entry_new();
 	meet->description	= gtk_text_view_new();
         buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(meet->description));
@@ -1388,6 +1456,7 @@ static VCalMeeting *vcal_meeting_create_real(VCalEvent *event, gboolean visible)
 		meet->method = (event->method == ICAL_METHOD_CANCEL ?
 				ICAL_METHOD_CANCEL:ICAL_METHOD_REQUEST);
 
+		gtk_entry_set_text(GTK_ENTRY(meet->location), event->location);
 		gtk_entry_set_text(GTK_ENTRY(meet->summary), event->summary);	
 		gtk_text_buffer_set_text(buffer, event->description, -1);	
 	} else 
@@ -1401,7 +1470,7 @@ static VCalMeeting *vcal_meeting_create_real(VCalEvent *event, gboolean visible)
                         (GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_SMALL_TOOLBAR);
 	meet->total_avail_msg = gtk_label_new("");
 	
-	gtk_widget_set_usize(meet->total_avail_evtbox, 18, 16);
+	gtk_widget_set_size_request(meet->total_avail_evtbox, 18, 16);
 	gtk_event_box_set_visible_window(GTK_EVENT_BOX(meet->total_avail_evtbox), FALSE);
 	gtk_container_add (GTK_CONTAINER(meet->total_avail_evtbox), meet->total_avail_img);
 
@@ -1424,16 +1493,15 @@ static VCalMeeting *vcal_meeting_create_real(VCalEvent *event, gboolean visible)
 		time_t t = time (NULL)+ 3600;
 		struct tm buft1, buft2;
  		struct tm *lt = localtime_r (&t, &buft1);
-		int num = -1;
 		mktime(lt);
 		gtk_calendar_select_day(GTK_CALENDAR(meet->start_c),
 					lt->tm_mday);
 		gtk_calendar_select_month(GTK_CALENDAR(meet->start_c),
 					lt->tm_mon, lt->tm_year + 1900);
 	
-		num = get_list_item_num(lt->tm_hour, 0);
-		if (num > -1)
-			gtk_list_select_item(GTK_LIST(GTK_COMBO(meet->start_time)->list), num);
+		time_text = g_strdup_printf("%02d:%02d", lt->tm_hour, 0);
+		combobox_select_by_text(GTK_COMBO_BOX(meet->start_time), time_text);
+		g_free(time_text);
 
 		t += 3600;
 		lt = localtime_r(&t, &buft2);
@@ -1443,9 +1511,9 @@ static VCalMeeting *vcal_meeting_create_real(VCalEvent *event, gboolean visible)
 		gtk_calendar_select_month(GTK_CALENDAR(meet->end_c),
 					lt->tm_mon, lt->tm_year + 1900);
 
-		num = get_list_item_num(lt->tm_hour, 0);
-		if (num > -1)
-			gtk_list_select_item(GTK_LIST(GTK_COMBO(meet->end_time)->list), num);
+		time_text = g_strdup_printf("%02d:%02d", lt->tm_hour, 0);
+		combobox_select_by_text(GTK_COMBO_BOX(meet->end_time), time_text);
+		g_free(time_text);
 
 	} else {
 		gtk_calendar_select_day(GTK_CALENDAR(meet->start_c),
@@ -1462,26 +1530,32 @@ static VCalMeeting *vcal_meeting_create_real(VCalEvent *event, gboolean visible)
 
 		num = get_list_item_num(get_dtdate(event->dtstart, HOUR), 
 					get_dtdate(event->dtstart, MINUTE));
-		if (num > -1)
-			gtk_list_select_item(GTK_LIST(GTK_COMBO(meet->start_time)->list), num);
-		else {
+		if (num > -1) {
+			time_text = g_strdup_printf("%02d:%02d", get_dtdate(event->dtstart, HOUR), 
+								 get_dtdate(event->dtstart, MINUTE));
+			combobox_select_by_text(GTK_COMBO_BOX(meet->start_time), time_text);
+			g_free(time_text);
+		} else {
 			gchar *tmp = g_strdup_printf("%02d:%02d",
 					get_dtdate(event->dtstart, HOUR), 
 					get_dtdate(event->dtstart, MINUTE));
-			gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(meet->start_time)->entry),
+			gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(meet->start_time))),
 					   tmp);
 			g_free(tmp);
 		}
 
 		num = get_list_item_num(get_dtdate(event->dtend, HOUR), 
 					get_dtdate(event->dtend, MINUTE));
-		if (num > -1)
-			gtk_list_select_item(GTK_LIST(GTK_COMBO(meet->end_time)->list), num);
-		else {
+		if (num > -1) {
+			time_text = g_strdup_printf("%02d:%02d", get_dtdate(event->dtend, HOUR), 
+								 get_dtdate(event->dtend, MINUTE));
+			combobox_select_by_text(GTK_COMBO_BOX(meet->end_time), time_text);
+			g_free(time_text);
+		} else {
 			gchar *tmp = g_strdup_printf("%02d:%02d",
 					get_dtdate(event->dtend, HOUR), 
 					get_dtdate(event->dtend, MINUTE));
-			gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(meet->end_time)->entry),
+			gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(meet->end_time))),
 					   tmp);
 			g_free(tmp);
 		}
@@ -1489,14 +1563,14 @@ static VCalMeeting *vcal_meeting_create_real(VCalEvent *event, gboolean visible)
 
 	g_signal_connect(G_OBJECT(meet->start_c), "day-selected",
 			 G_CALLBACK(meeting_start_changed), meet);
-	g_signal_connect(G_OBJECT(GTK_COMBO(meet->start_time)->entry),
+	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN(meet->start_time))),
 			 "changed",
 			 G_CALLBACK(meeting_start_changed),
 			 meet);
 
 	g_signal_connect(G_OBJECT(meet->end_c), "day-selected",
 			 G_CALLBACK(meeting_end_changed), meet);
-	g_signal_connect(G_OBJECT(GTK_COMBO(meet->end_time)->entry),
+	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN(meet->end_time))),
 			 "changed",
 			 G_CALLBACK(meeting_end_changed),
 			 meet);
@@ -1591,7 +1665,7 @@ static VCalMeeting *vcal_meeting_create_real(VCalEvent *event, gboolean visible)
 		if (ac->protocol == A_NNTP) {
 			continue;
 		}
-		if (!event && ac == cur_account) {
+		if (!event && ac == account_get_cur_account()) {
 			num = i;
 		}
 		else if (event && !strcmp(ac->address, event->organizer))
@@ -1623,7 +1697,7 @@ static VCalMeeting *vcal_meeting_create_real(VCalEvent *event, gboolean visible)
 	gtk_box_pack_start(GTK_BOX(hbox), meet->avail_evtbox, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), meet->who, TRUE, TRUE, 0);
 
-	gtk_widget_set_usize(meet->avail_evtbox, 18, 16);
+	gtk_widget_set_size_request(meet->avail_evtbox, 18, 16);
 	gtk_event_box_set_visible_window(GTK_EVENT_BOX(meet->avail_evtbox), FALSE);
 	gtk_container_add (GTK_CONTAINER(meet->avail_evtbox), meet->avail_img);
 
@@ -1631,6 +1705,7 @@ static VCalMeeting *vcal_meeting_create_real(VCalEvent *event, gboolean visible)
 	TABLE_ADD_LINE(_("Organizer:"), hbox, FALSE);
 	TABLE_ADD_LINE(_("Summary:"), meet->summary, TRUE);
 	TABLE_ADD_LINE(_("Time:"), date_hbox, TRUE);
+	TABLE_ADD_LINE(_("Location:"), meet->location, TRUE);
 	TABLE_ADD_LINE(_("Description:"), scrolledwin, TRUE);
 	TABLE_ADD_LINE(_("Attendees:"), meet->attendees_vbox, FALSE);
 	TABLE_ADD_LINE("", save_hbox, TRUE);
@@ -1640,6 +1715,7 @@ static VCalMeeting *vcal_meeting_create_real(VCalEvent *event, gboolean visible)
 #else
 	TABLE_ADD_LINE(_("Organizer:"), hbox, FALSE, TRUE);
 	TABLE_ADD_LINE(_("Summary:"), meet->summary, TRUE, TRUE);
+	TABLE_ADD_LINE(_("Location:"), meet->location, FALSE, TRUE);
 	TABLE_ADD_LINE(_("Description:"), scrolledwin, TRUE, TRUE);
 	TABLE_ADD_LINE(_("Attendees:"), meet->attendees_vbox, FALSE, TRUE);
 	TABLE_ADD_LINE("", date_hbox, TRUE, FALSE);
@@ -1701,14 +1777,21 @@ VCalMeeting *vcal_meeting_create_with_start(VCalEvent *event, struct tm *sdate)
 
 	if (sdate->tm_hour != 0) {
 		num = get_list_item_num(sdate->tm_hour, 0);
-		if (num > -1)
-			gtk_list_select_item(GTK_LIST(GTK_COMBO(meet->start_time)->list), num);
+		if (num > -1) {
+			gchar *time_text = g_strdup_printf("%02d:%02d", sdate->tm_hour, 0);
+			combobox_select_by_text(GTK_COMBO_BOX(meet->start_time), time_text);
+			g_free(time_text);
+		} 
 		if (sdate->tm_hour < 23) {
 			num = get_list_item_num(sdate->tm_hour+1, 0);
-			if (num > -1)
-				gtk_list_select_item(GTK_LIST(GTK_COMBO(meet->end_time)->list), num);
+			if (num > -1) {
+				gchar *time_text = g_strdup_printf("%02d:%02d", sdate->tm_hour+1, 0);
+				combobox_select_by_text(GTK_COMBO_BOX(meet->end_time), time_text);
+				g_free(time_text);
+			} 
 		} else {
 			struct tm tm_tomorrow;
+			gchar *time_text;
 			tm_tomorrow.tm_mday = sdate->tm_mday;
 			tm_tomorrow.tm_mon = sdate->tm_mon;
 			tm_tomorrow.tm_wday = sdate->tm_wday;
@@ -1719,7 +1802,10 @@ VCalMeeting *vcal_meeting_create_with_start(VCalEvent *event, struct tm *sdate)
 						tm_tomorrow.tm_mday);
 			gtk_calendar_select_month(GTK_CALENDAR(meet->end_c),
 						tm_tomorrow.tm_mon, tm_tomorrow.tm_year);
-			gtk_list_select_item(GTK_LIST(GTK_COMBO(meet->end_time)->list), 0);
+			
+			time_text = g_strdup_printf("%02d:%02d", 0, 0);
+			combobox_select_by_text(GTK_COMBO_BOX(meet->end_time), time_text);
+			g_free(time_text);
 		}
 	}
 	return meet;
@@ -1795,10 +1881,12 @@ gint vcal_meeting_alert_check(gpointer data)
 			title = g_strdup_printf(_("Upcoming event: %s"), event->summary);
 			message = g_strdup_printf(_("You have a meeting or event soon.\n"
 					 "It starts at %s and ends %s later.\n"
+                     "Location: %s\n"
 					 "More information:\n\n"
 					 "%s"),
 						estart,
 						duration,
+						event->location?event->location:"",
 						event->description);
 
 			g_free(duration);
@@ -1890,7 +1978,7 @@ void multisync_export(void)
 	g_slist_free(list);
 	
 	file = g_strconcat(path, G_DIR_SEPARATOR_S, "backup_entries", NULL);
-	fp = fopen(file, "wb");
+	fp = g_fopen(file, "wb");
 	g_free(file);
 	if (fp) {
 		for (cur = files; cur; cur = cur->next) {
@@ -2021,7 +2109,7 @@ putfile:
 		g_free(afile);
 		g_free(file);
 	} else if (file) {
-		FILE *fp = fopen(tmpfile, "rb");
+		FILE *fp = g_fopen(tmpfile, "rb");
 		if (!strncmp(file, "webcal://", 9)) {
 			gchar *tmp = g_strdup_printf("http://%s", file+9);
 			g_free(file);
@@ -2168,7 +2256,7 @@ gboolean vcal_meeting_export_freebusy(const gchar *path, const gchar *user,
 		g_free(afile);
 		g_free(file);
 	} else if (file) {
-		FILE *fp = fopen(tmpfile, "rb");
+		FILE *fp = g_fopen(tmpfile, "rb");
 		if (!strncmp(file, "webcal://", 9)) {
 			gchar *tmp = g_strdup_printf("http://%s", file+9);
 			g_free(file);
